# ACT I

### SCENE I. London. A room of state in the palace.

*Enter King Edward, Derby, Prince Edward, Audley, and 
Artois.*

**KING EDWARD**  
Robert of Artois, banished though thou be  
From France, thy native Country, yet with us  
Thou shalt retain as great a Seigniorie:  
For we create thee Earl of Richmond here.  
And now go forwards with our pedigree:  
Who next succeeded Philip le Bew?

**ARTOIS**  
Three sons of his, which all successfully  
Did sit upon their father's regal throne,  
Yet died, and left no issue of their loins.

**KING EDWARD**  
But was my mother sister unto those?

**ARTOIS**  
She was, my Lord; and only Isabel  
Was all the daughters that this Philip had,  
Whom afterward your father took to wife;  
And from the fragrant garden of her womb  
Your gracious self, the flower of Europe's hope,  
Derived is inheritor to France.  
But note the rancor of rebellious minds:  
When thus the lineage of le Bew was out,  
The French obscured your mother's privilege,  
And, though she were the next of blood, proclaimed  
John, of the house of Valois, now their King:  
The reason was, they say, the realm of France,  
Replete with princes of great parentage,  
Ought not admit a governor to rule,  
Except he be descended of the male;  
And that's the special ground of their contempt,  
Wherewith they study to exclude your grace:  
But they shall find that forged ground of theirs  
To be but dusty heaps of brittle sand.  
Perhaps it will be thought a heinous thing,  
That I, a Frenchman, should discover this;  
But heaven I call to record of my vows:  
It is not hate nor any private wrong,  
But love unto my country and the right,  
Provokes my tongue, thus lavish in report.  
You are the lineal watchman of our peace,  
And John of Valois indirectly climbs;  
What then should subjects but embrace their King?  
Ah, where in may our duty more be seen,  
Than striving to rebate a tyrant's pride  
And place the true shepherd of our commonwealth?

**KING EDWARD**  
This counsel, Artois, like to fruitful showers,  
Hath added growth unto my dignity;  
And, by the fiery vigor of thy words,  
Hot courage is engendered in my breast,  
Which heretofore was raked in ignorance,  
But now doth mount with golden wings of fame,  
And will approve fair Isabel's descent,  
Able to yoke their stubborn necks with steel,  
That spurn against my sovereignty in France.

*Sound a horn.*

A messenger?—Lord Audley, know from whence.

*Exit Audley, and returns.*

**AUDLEY**  
The Duke of Lorraine, having crossed the seas,  
Entreats he may have conference with your highness.

**KING EDWARD**  
Admit him, lords, that we may hear the news.

*Exeunt lords.*

*King takes his State.*

*Re-enter lords; with Lorraine, attended.*

Say, Duke of Lorraine, wherefore art thou come?

**LORRAINE**  
The most renowned Prince, King John of France,  
Doth greet thee, Edward, and by me commands,  
That, for so much as by his liberal gift  
The Guyen Dukedom is entailed to thee,  
Thou do him lowly homage for the same.  
And, for that purpose, here I summon thee,  
Repair to France within these forty days,  
That there, according as the custom is,  
Thou mayst be sworn true liegeman to our King;  
Or else thy title in that province dies,  
And he himself will repossess the place.

**KING EDWARD**  
See, how occasion laughs me in the face!  
No sooner minded to prepare for France,  
But straight I am invited — nay, with threats,  
Upon a penalty, enjoined to come:  
'Twere but a childish part to say him nay.—  
Lorraine, return this answer to thy Lord:  
I mean to visit him as he requests;  
But how? Not servilely disposed to bend,  
But like a conqueror to make him bow.  
His lame unpolished shifts are come to light;  
And truth hath pulled the vizard from his face,  
That set a gloss upon his arrogance.  
Dare he command a fealty in me?  
Tell him, the Crown that he usurps, is mine,  
And where he sets his foot, he ought to kneel.  
'Tis not a petty dukedom that I claim,  
But all the whole dominions of the realm;  
Which if with grudging he refuse to yield,  
I'll take away those borrowed plumes of his,  
And send him naked to the wilderness.

**LORRAINE**  
Then, Edward, here, in spite of all thy lords,  
I do pronounce defiance to thy face.

**PRINCE EDWARD**  
Defiance, Frenchman? We rebound it back,  
Even to the bottom of thy master's throat.  
And, be it spoke with reverence of the King,  
My gracious father, and these other lords,  
I hold thy message but as scurrilous,  
And him that sent thee, like the lazy drone,  
Crept up by stealth unto the eagle's nest;  
From whence we'll shake him with so rough a storm,  
As others shall be warned by his harm.

**WARWICK**  
Bid him leave of the lion's case he wears,  
Least, meeting with the lion in the field,  
He chance to tear him piecemeal for his pride.

**ARTOIS**  
The soundest counsel I can give his grace,  
Is to surrender ere he be constrained.  
A voluntary mischief hath less scorn,  
Than when reproach with violence is borne.

**LORRAINE**  
Degenerate traitor, viper to the place  
Where thou was fostered in thine infancy,  
Bearest thou a part in this conspiracy?  
*[He draws his sword.]*

**KING EDWARD**  
Lorraine, behold the sharpness of this steel:  
*[Drawing his.]*

Fervent desire that sits against my heart,  
Is far more thorny pricking than this blade;  
That, with the nightingale, I shall be scared,  
As oft as I dispose myself to rest,  
Until my colors be displayed in France:  
This is my final answer; so be gone.

**LORRAINE**  
It is not that, nor any English brave,  
Afflicts me so, as doth his poisoned view,  
That is most false, should most of all be true.

*Exeunt Lorraine, and Train.*

**KING EDWARD**  
Now, Lord, our fleeting bark is under sail;  
Our gage is thrown, and war is soon begun,  
But not so quickly brought unto an end.

*Enter Mountague.*

But wherefore comes Sir William Mountague?  
How stands the league between the Scot and us?

**MOUNTAGUE**  
Cracked and dissevered, my renowned Lord.  
The treacherous King no sooner was informed  
Of your with drawing of your army back,  
But straight, forgetting of his former oath,  
He made invasion on the bordering Towns:  
Barwick is won, Newcastle spoiled and lost,  
And now the tyrant hath begirt with siege  
The castle of Rocksborough, where enclos'd  
The Countess Salisbury is like to perish.

**KING EDWARD**  
That is thy daughter, Warwick, is it not?  
Whose husband hath in Bretagne served so long  
About the planting of Lord Mountford there?

**WARWICK**  
It is, my Lord.  

**KING EDWARD**  
Ignoble David! hast thou none to grieve  
But silly Ladies with thy threatening arms?  
But I will make you shrink your snaily horns!  
First, therefore, Audley, this shall be thy charge,  
Go levy footmen for our wars in France;  
And, Ned, take muster of our men at arms:  
In every shire elect a several band.  
Let them be Soldiers of a lusty spirit,  
Such as dread nothing but dishonor's blot;  
Be wary, therefore, since we do commence  
A famous war, and with so mighty a nation.  
Derby, be thou ambassador for us  
Unto our father in law, the Earl of Henalt:  
Make him acquainted with our enterprise,  
And likewise will him, with our own allies  
That are in Flanders, to solicit to  
The Emperor of Almaigne in our name.  
Myself, whilst you are jointly thus employed,  
Will, with these forces that I have at hand,  
March, and once more repulse the traitorous Scot.  
But, Sirs, be resolute: we shall have wars  
On every side; and, Ned, thou must begin  
Now to forget thy study and thy books,  
And ure thy shoulders to an armor's weight.

**PRINCE EDWARD**  
As cheerful sounding to my youthful spleen  
This tumult is of war's increasing broils,  
As, at the coronation of a King,  
The joyful clamors of the people are,  
When "Ave, Caesar!" they pronounce aloud.  
Within this school of honor I shall learn  
Either to sacrifice my foes to death,  
Or in a rightful quarrel spend my breath.  
Then cheerfully forward, each a several way;  
In great affairs 'tis nought to use delay.

*Exeunt.*

### SCENE II. Roxborough. Before the castle.

*Enter the Countess.*

**COUNTESS**  
Alas, how much in vain my poor eyes gaze  
For succor that my sovereign should send!  
Ah, cousin Mountague, I fear thou wants  
The lively spirit, sharply to solicit  
With vehement suit the King in my behalf:  
Thou do'st not tell him, what a grief it is  
To be the scornful captive of a Scot,  
Either to be wooed with broad untuned oaths,  
Or forced by rough insulting barbarism;  
Thou doest not tell him, if he here prevail,  
How much they will deride us in the north,  
And, in their wild, uncivil, skipping gigs,  
Bray forth their conquest and our overthrow  
Even in the barren, bleak, and fruitless air.

*Enter David and Douglas, Lorraine.*

I must withdraw, the everlasting foe  
Comes to the wall; I'll closely step aside,  
And list their babble, blunt and full of pride.

**KING DAVID**  
My Lord of Lorraine, to our brother of France  
Commend us, as the man in Christendom  
That we most reverence and entirely love.  
Touching your embassage, return and say,  
That we with England will not enter parley,  
Nor never make fair weather, or take truce;  
But burn their neighbor towns, and so persist  
With eager roads beyond their city York.  
And never shall our bonny riders rest,  
Nor rusting canker have the time to eat  
Their light borne snaffles nor their nimble spurs,  
Nor lay aside their Jacks of Gymould mayle,  
Nor hang their staves of grained Scottish ash  
In peaceful wise upon their city walls,  
Nor from their buttoned tawny leathern belts  
Dismiss their biting whinyards, till your King  
Cry out, "Enough! Spare England now for pity!"  
Farewell, and tell him that you leave us here  
Before this castle; say, you came from us,  
Even when we had that yielded to our hands.

**LORRAINE**  
I take my leave, and fairly will return  
Your acceptable greeting to my King.

*Exit Lorraine.*

**KING DAVID**  
Now, Douglas, to our former task again,  
For the division of this certain spoil.

**DOUGLAS**  
My liege, I crave the Lady, and no more.

**KING DAVID**  
Nay, soft ye, sir; first I must make my choice,  
And first I do bespeak her for myself.

**DOUGLAS**  
Why then, my liege, let me enjoy her jewels.

**KING DAVID**  
Those are her own, still liable to her,  
And who inherits her, hath those with all.

*Enter First Scottish Messenger in haste.*

**First Scottish Messenger**  
My liege, as we were pricking on the hills,  
To fetch in booty, marching hitherward,  
We might descry a might host of men;  
The sun, reflecting on the armor, shewed  
A field of plate, a wood of picks advanced.  
Bethink your highness speedily herein:  
An easy march within four hours will bring  
The hindmost rank unto this place, my liege.

**KING DAVID**  
Dislodge, dislodge! It is the King of England.

**DOUGLAS**  
Jemmy, my man, saddle my bonny black.

**KING DAVID**  
Mean'st thou to fight, Douglas? We are too weak.

**DOUGLAS**  
I know it well, my liege, and therefore fly.

**COUNTESS**  
*[Coming forward.]*  
My lords of Scotland, will ye stay and drink?

**KING DAVID**  
She mocks at us, Douglas; I cannot endure it.

**COUNTESS**  
Say, good my Lord, which is he must have the Lady,  
And which her jewels? I am sure, my Lords,  
Ye will not hence, till you have shared the spoils.

**KING DAVID**  
She heard the messenger, and heard our talk;  
And now that comfort makes her scorn at us.

*Enter Second Scottish Messenger.*

**Second Scottish Messenger**  
Arm, my good Lord! O, we are all surprised!

**COUNTESS**  
After the French ambassador, my liege,  
And tell him, that you dare not ride to York;  
Excuse it that your bonny horse is lame.

**KING DAVID**  
She heard that too; intolerable grief!  
Woman, farewell! Although I do not stay...

*Exeunt Scots.*

**COUNTESS**  
'Tis not for fear, and yet you run away.—  
O happy comfort, welcome to our house!  
The confident and boisterous boasting Scot,  
That swore before my walls they would not back  
For all the armed power of this land,  
With faceless fear that ever turns his back,  
Turned hence against the blasting north-east wind  
Upon the bare report and name of arms.

*Enter Mountague.*

O Summer's day! See where my Cousin comes!

**MOUNTAGUE**  
How fares my Aunt? We are not Scots;  
Why do you shut your gates against your friends?

**COUNTESS**  
Well may I give a welcome, cousin, to thee,  
For thou comst well to chase my foes from hence.

**MOUNTAGUE**  
The King himself is come in person hither;  
Dear aunt, descend, and gratulate his highness.

**COUNTESS**  
How may I entertain his majesty,  
To shew my duty and his dignity?

*Exit, from above.*

*Enter King Edward, Warwick, Artois, with others.*

**KING EDWARD**  
What, are the stealing Foxes fled and gone,  
Before we could uncouple at their heels?

**WARWICK**  
They are, my liege; but, with a cheerful cry,  
Hot hounds and hardy chase them at the heels.

*Enter Countess.*

**KING EDWARD**  
This is the Countess, Warwick, is it not?  

**WARWICK**  
Even she, my liege; whose beauty tyrants fear,  
As a May blossom with pernicious winds,  
Hath sullied, withered, overcast, and done.

**KING EDWARD**  
Hath she been fairer, Warwick, than she is?

**WARWICK**  
My gracious King, fair is she not at all,  
If that herself were by to stain herself,  
As I have scene her when she was herself.

**KING EDWARD**  
What strange enchantment lurked in those her eyes,  
When they excelled this excellence they have,  
That now her dim decline hath power to draw  
My subject eyes from persing majesty,  
To gaze on her with doting admiration?

**COUNTESS**  
In duty lower than the ground I kneel,  
And for my dull knees bow my feeling heart,  
To witness my obedience to your highness,  
With many millions of a subject's thanks  
For this your royal presence, whose approach  
Hath driven war and danger from my gate.

**KING EDWARD**  
Lady, stand up; I come to bring thee peace,  
However thereby I have purchased war.  

**COUNTESS**  
No war to you, my liege; the Scots are gone,  
And gallop home toward Scotland with their hate.

**KING EDWARD**  
Least, yielding here, I pine in shameful love,  
Come, we'll pursue the Scots;—Artois, away!

**COUNTESS**  
A little while, my gracious sovereign, stay,  
And let the power of a mighty King  
Honor our roof; my husband in the wars,  
When he shall hear it, will triumph for joy;  
Then, dear my liege, now niggard not thy state:  
Being at the wall, enter our homely gate.

**KING EDWARD**  
Pardon me, countess, I will come no near;  
I dreamed tonight of treason, and I fear.

**COUNTESS**  
Far from this place let ugly treason lie!

**KING EDWARD**  
No farther off, than her conspiring eye,  
Which shoots infected poison in my heart,  
Beyond repulse of wit or cure of art.  
Now, in the sun alone it doth not lie,  
With light to take light from a mortal eye;  
For here two day stars that mine eyes would see  
More than the sun steals mine own light from me,  
Contemplative desire, desire to be  
In contemplation, that may master thee!  
Warwick, Artois, to horse and let's away!

**COUNTESS**  
What might I speak to make my sovereign stay?

**KING EDWARD**  
What needs a tongue to such a speaking eye,  
That more persuades than winning Oratory?

**COUNTESS**  
Let not thy presence, like the April sun,  
Flatter our earth and suddenly be done.  
More happy do not make our outward wall  
Than thou wilt grace our inner house withal.  
Our house, my liege, is like a country swain,  
Whose habit rude and manners blunt and plain  
Presageth nought, yet inly beautified  
With bounties, riches and faire hidden pride.  
For where the golden ore doth buried lie,  
The ground, undecked with nature's tapestry,  
Seems barren, sere, unfertile, fructless, dry;  
And where the upper turf of earth doth boast  
His pied perfumes and party colored coat,  
Delve there, and find this issue and their pride  
To spring from ordure and corruption's side.  
But, to make up my all too long compare,  
These ragged walls no testimony are,  
What is within; but, like a cloak, doth hide  
From weather's Waste the under garnished pride.  
More gracious then my terms can let thee be,  
Intreat thyself to stay a while with me.

**KING EDWARD**  
As wise, as fair; what fond fit can be heard,  
When wisdom keeps the gate as beauty's guard?—  
It shall attend, while I attend on thee:  
Come on, my lords; here will I host tonight.

*Exeunt.*

# ACT II  

### SCENE I. Roxborough. The gardens of the castle.

*Enter Lodowick.*

**LODOWICK**  
I might perceive his eye in her eye lost,  
His ear to drink her sweet tongue's utterance,  
And changing passion, like inconstant clouds  
That rack upon the carriage of the winds,  
Increase and die in his disturbed cheeks.  
Lo, when she blushed, even then did he look pale,  
As if her cheeks by some enchanted power  
Attracted had the cherry blood from his:  
Anon, with reverent fear when she grew pale,  
His cheeks put on their scarlet ornaments;  
But no more like her oriental red,  
Than brick to coral or live things to dead.  
Why did he then thus counterfeit her looks?  
If she did blush, twas tender modest shame,  
Being in the sacred presence of a King;  
If he did blush, twas red immodest shame,  
To veil his eyes amiss, being a King;  
If she looked pale, twas silly woman's fear,  
To bear herself in presence of a King;  
If he looked pale, it was with guilty fear,  
To dote amiss, being a mighty King.  
Then, Scottish wars, farewell; I fear twill prove  
A lingering English siege of peevish love.  
Here comes his highness, walking all alone.

*Enter King Edward.*

**KING EDWARD**  
She is grown more fairer far since I came hither,  
Her voice more silver every word than other,  
Her wit more fluent. What a strange discourse  
Unfolded she of David and his Scots!  
"Even thus," quoth she, "he spake," and then spoke broad,  
With epithites and accents of the Scot,  
But somewhat better than the Scot could speak:  
"And thus," quoth she, and answered then herself—  
For who could speak like her but she herself—  
Breathes from the wall an angel's note from heaven  
Of sweet defiance to her barbarous foes.  
When she would talk of peace, methinks, her tongue  
Commanded war to prison; when of war,  
It wakened Caesar from his Roman grave,  
To hear war beautified by her discourse.  
Wisdom is foolishness but in her tongue,  
Beauty a slander but in her fair face,  
There is no summer but in her cheerful looks,  
Nor frosty winter but in her disdain.  
I cannot blame the Scots that did besiege her,  
For she is all the treasure of our land;  
But call them cowards, that they ran away,  
Having so rich and fair a cause to stay.—  
Art thou there, Lodowick? Give me ink and paper.

**LODOWICK**  
I will, my liege.

**KING EDWARD**  
And bid the lords hold on their play at chess,  
For we will walk and meditate alone.

**LODOWICK**  
I will, my sovereign.

*Exit Lodowick.*

**KING EDWARD**  
This fellow is well read in poetry,  
And hath a lusty and persuasive spirit;  
I will acquaint him with my passion,  
Which he shall shadow with a veil of lawn,  
Through which the queen of beauty's queen shall see  
Her self the ground of my infirmity.

*Enter Lodowick.*

**KING EDWARD**  
Hast thou pen, ink, and paper ready, Lodowick?

**LODOWICK**  
Ready, my liege.

**KING EDWARD**  
Then in the summer arbor sit by me,  
Make it our counsel house or cabinet:  
Since green our thoughts, green be the conventicle,  
Where we will ease us by disburdening them.  
Now, Lodowick, invocate some golden muse,  
To bring thee hither an enchanted pen,  
That may for sighs set down true sighs indeed,  
Talking of grief, to make thee ready groan;  
And when thou writest of tears, encouch the word  
Before and after with such sweet laments,  
That it may raise drops in a Tartar's eye,  
And make a flintheart Scythian pitiful;  
For so much moving hath a Poet's pen:  
Then, if thou be a poet, move thou so,  
And be enriched by thy sovereign's love.  
For, if the touch of sweet concordant strings  
Could force attendance in the ears of hell,  
How much more shall the strains of poets' wit  
Beguile and ravish soft and humane minds?

**LODOWICK**  
To whom, my Lord, shall I direct my stile?

**KING EDWARD**  
To one that shames the fair and sots the wise;  
Whose bod is an abstract or a brief,  
Contains each general virtue in the world.  
Better than beautiful thou must begin,  
Devise for fair a fairer word than fair,  
And every ornament that thou wouldest praise,  
Fly it a pitch above the soar of praise.  
For flattery fear thou not to be convicted;  
For, were thy admiration ten times more,  
Ten times ten thousand more the worth exceeds  
Of that thou art to praise, thy praises worth.  
Begin; I will to contemplate the while:  
Forget not to set down, how passionate,  
How heart sick, and how full of languishment,  
Her beauty makes me. ...

**LODOWICK**  
... Write I to a woman?

**KING EDWARD**  
What beauty else could triumph over me,  
Or who but women do our love lays greet?  
What, thinkest thou I did bid thee praise a horse?

**LODOWICK**  
Of what condition or estate she is,  
'Twere requisite that I should know, my Lord.

**KING EDWARD**  
Of such estate, that hers is as a throne,  
And my estate the footstool where she treads:  
Then mayst thou judge what her condition is  
By the proportion of her mightiness.  
Write on, while I peruse her in my thoughts.—  
Her voice to music or the nightingale—  
To music every summer leaping swain  
Compares his sunburnt lover when she speaks;  
And why should I speak of the nightingale?  
The nightingale sings of adulterate wrong,  
And that, compared, is too satyrical;  
For sin, though sin, would not be so esteemed,  
But, rather, virtue sin, sin virtue deemed.  
Her hair, far softer than the silk worm's twist,  
Like to a flattering glass, doth make more fair  
The yellow Amber: — like a flattering glass  
Comes in too soon; for, writing of her eyes,  
I'll say that like a glass they catch the sun,  
And thence the hot reflection doth rebound  
Against the breast, and burns my heart within.  
Ah, what a world of descant makes my soul  
Upon this voluntary ground of love!—  
Come, Lodowick, hast thou turned thy ink to gold?  
If not, write but in letters capital  
My mistress' name, and it will gild thy paper:  
Read, Lord, read;  
Fill thou the empty hollows of mine ears  
With the sweet hearing of thy poetry.

**LODOWICK**  
I have not to a period brought her praise.

**KING EDWARD**  
Her praise is as my love, both infinite,  
Which apprehend such violent extremes,  
That they disdain an ending period.  
Her beauty hath no match but my affection;  
Hers more than most, mine most and more than more:  
Hers more to praise than tell the sea by drops,  
Nay, more than drop the massy earth by sands,  
And sand by sand print them in memory:  
Then wherefore talkest thou of a period  
To that which craves unended admiration?  
Read, let us hear.

**LODOWICK**  
*[Reads.]*  
More fair and chaste than is the queen of shades,—

**KING EDWARD**  
That line hath two faults, gross and palpable:  
Comparest thou her to the pale queen of night,  
Who, being set in dark, seems therefore light?  
What is she, when the sun lifts up his head,  
But like a fading taper, dim and dead?  
My love shall brave the eye of heaven at noon,  
And, being unmasked, outshine the golden sun.

**LODOWICK**  
What is the other fault, my sovereign Lord?

**KING EDWARD**  
Read o'er the line again.

**LODOWICK**  
*[Reads.]*  
More fair and chaste— 

**KING EDWARD**  
I did not bid thee talk of chastity,  
To ransack so the treasure of her mind;  
For I had rather have her chased than chaste.  
Out with the moon line, I will none of it;  
And let me have her likened to the sun:  
Say she hath thrice more splendor than the sun,  
That her perfections emulate the sun,  
That she breeds sweets as plenteous as the sun,  
That she doth thaw cold winter like the sun,  
That she doth cheer fresh summer like the sun,  
That she doth dazzle gazers like the sun;  
And, in this application to the sun,  
Bid her be free and general as the sun,  
Who smiles upon the basest weed that grows  
As lovingly as on the fragrant rose.  
Let's see what follows that same moonlight line.

**LODOWICK**  
*[Reads.]*  
More fair and chaste than is the queen of shades,  
More bold in constance— ...

**KING EDWARD**  
... In constance! Than who?

**LODOWICK**  
*[Reads.]*  
Than Judith was.

**KING EDWARD**  
O monstrous line! Put in the next a sword,  
And I shall woo her to cut off my head.  
Blot, blot, good Lodowick! Let us hear the next.

**LODOWICK**  
There's all that yet is done.

**KING EDWARD**  
I thank thee then; thou hast done little ill,  
But what is done, is passing, passing ill.  
No, let the captain talk of boisterous war,  
The prisoner of emured dark constraint,  
The sick man best sets down the pangs of death,  
The man that starves the sweetness of a feast,  
The frozen soul the benefit of fire,  
And every grief his happy opposite:  
Love cannot sound well but in lover's tongues;  
Give me the pen and paper, I will write.

*Enter Countess.*

But soft, here comes the treasurer of my spirit.—  
Lodowick, thou know'st not how to draw a battle;  
These wings, these flankers, and these squadrons  
Argue in thee defective discipline:  
Thou shouldest have placed this here, this other here.

**COUNTESS**  
Pardon my boldness, my thrice gracious lords;  
Let my intrusion here be called my duty,  
That comes to see my sovereign how he fares.

**KING EDWARD**  
Go, draw the same, I tell thee in what form.

**LODOWICK**  
I go.

*Exit Lodowick.*

**COUNTESS**  
Sorry I am to see my liege so sad:  
What may thy subject do to drive from thee  
Thy gloomy consort, sollemn melancholy?

**KING EDWARD**  
Ah, Lady, I am blunt and cannot straw  
The flowers of solace in a ground of shame:—  
Since I came hither, Countess, I am wronged.

**COUNTESS**  
Now God forbid that any in my house  
Should think my sovereign wrong! Thrice gentle King,  
Acquaint me with your cause of discontent.

**KING EDWARD**  
How near then shall I be to remedy?

**COUNTESS**  
As near, my liege, as all my woman's power  
Can pawn itself to buy thy remedy.

**KING EDWARD**  
If thou speakst true, then have I my redress:  
Engage thy power to redeem my Joys,  
And I am joyful, Countess; else I die.

**COUNTESS**  
I will, my Liege. ...

**KING EDWARD**  
... Swear, Countess, that thou wilt.

**COUNTESS**  
By heaven, I will.

**KING EDWARD**  
Then take thyself a little way a side,  
And tell thyself, a King doth dote on thee;  
Say that within thy power it doth lie  
To make him happy, and that thou hast sworn  
To give him all the joy within thy power:  
Do this, and tell me when I shall be happy.

**COUNTESS**  
All this is done, my thrice dread sovereign:  
That power of love, that I have power to give,  
Thou hast with all devout obedience;  
Employ me how thou wilt in proof thereof.

**KING EDWARD**  
Thou hear'st me say that I do dote on thee.

**COUNTESS**  
If on my beauty, take it if thou canst;  
Though little, I do prize it ten times less;  
If on my virtue, take it if thou canst,  
For virtue's store by giving doth augment;  
Be it on what it will, that I can give  
And thou canst take away, inherit it.

**KING EDWARD**  
It is thy beauty that I would enjoy.

**COUNTESS**  
O, were it painted, I would wipe it off  
And dispossess myself, to give it thee.  
But, sovereign, it is soldered to my life:  
Take one and both; for, like an humble shadow,  
It haunts the sunshine of my summer's life.

**KING EDWARD**  
But thou mayst lend it me to sport with all.

**COUNTESS**  
As easy may my intellectual soul  
Be lent away, and yet my body live,  
As lend my body, palace to my soul,  
Away from her, and yet retain my soul.  
My body is her bower, her court, her abbey,  
And she an angel, pure, divine, unspotted:  
If I should leave her house, my Lord, to thee,  
I kill my poor soul and my poor soul me.

**KING EDWARD**  
Didst thou not swear to give me what I would?

**COUNTESS**  
I did, my liege, so what you would I could.

**KING EDWARD**  
I wish no more of thee than thou mayst give:—  
Nor beg I do not, but I rather buy—  
That is, thy love; and for that love of thine  
In rich exchange I tender to thee mine.

**COUNTESS**  
But that your lips were sacred, my Lord,  
You would profane the holy name of love.  
That love you offer me you cannot give,  
For Caesar owes that tribute to his queen;  
That love you beg of me I cannot give,  
For Sara owes that duty to her Lord.  
He that doth clip or counterfeit your stamp  
Shall die, my Lord; and will your sacred self  
Commit high treason against the King of Heaven,  
To stamp his image in forbidden metal,  
Forgetting your allegiance and your oath?  
In violating marriage sacred law,  
You break a greater honor than yourself:  
To be a King is of a younger house  
Than to be married; your progenitour,  
Sole reigning Adam on the universe,  
By God was honored for a married man,  
But not by him anointed for a King.  
It is a penalty to break your statutes,  
Though not enacted with your highness' hand:  
How much more, to infringe the holy act,  
Made by the mouth of God, sealed with his hand?  
I know, my sovereign, in my husband's love,  
Who now doth loyal service in his wars,  
Doth but so try the wife of Salisbury,  
Whither she will hear a wanton's tale or no,  
Lest being therein guilty by my stay,  
From that, not from my liege, I turn away.

*Exit.*

**KING EDWARD**  
Whether is her beauty by her words dying,  
Or are her words sweet chaplains to her beauty?  
Like as the wind doth beautify a sail,  
And as a sail becomes the unseen wind,  
So do her words her beauties, beauties words.  
O, that I were a honey gathering bee,  
To bear the comb of virtue from this flower,  
And not a poison sucking envious spider,  
To turn the juice I take to deadly venom!  
Religion is austere and beauty gentle;  
Too strict a guardian for so fair a ward!  
O, that she were, as is the air, to me!  
Why, so she is, for when I would embrace her,  
This do I, and catch nothing but myself.  
I must enjoy her; for I cannot beat  
With reason and reproof fond love a way.

*Enter Warwick.*

Here comes her father: I will work with him,  
To bear my colors in this field of love.

**WARWICK**  
How is it that my sovereign is so sad?  
May I with pardon know your highness grief;  
And that my old endeavor will remove it,  
It shall not cumber long your majesty.

**KING EDWARD**  
A kind and voluntary gift thou proferest,  
That I was forward to have begged of thee.  
But, O thou world, great nurse of flattery,  
Why dost thou tip men's tongues with golden words,  
And peise their deeds with weight of heavy lead,  
That fair performance cannot follow promise?  
O, that a man might hold the heart's close book  
And choke the lavish tongue, when it doth utter  
The breath of falsehood not charactered there!

**WARWICK**  
Far be it from the honor of my age,  
That I should owe bright gold and render lead;  
Age is a cynic, not a flatterer.  
I say again, that if I knew your grief,  
And that by me it may be lessened,  
My proper harm should buy your Highness' good.

**KING EDWARD**  
These are the vulgar tenders of false men,  
That never pay the duty of their words.  
Thou wilt not stick to swear what thou hast said;  
But, when thou knowest my grief's condition,  
This rash disgorged vomit of thy word  
Thou wilt eat up again, and leave me helpless.

**WARWICK**  
By heaven, I will not, though your majesty  
Did bid me run upon your sword and die.

**KING EDWARD**  
Say that my grief is no way medicinable  
But by the loss and bruising of thine honor.

**WARWICK**  
If nothing but that loss may vantage you,  
I would accompt that loss my vantage too.

**KING EDWARD**  
Thinkst that thou canst unswear thy oath again?

**WARWICK**  
I cannot; nor I would not, if I could.

**KING EDWARD**  
But, if thou do'st, what shall I say to thee?  

**WARWICK**  
What may be said to any perjured villain,  
That breaks the sacred warrant of an oath.

**KING EDWARD**  
What wilt thou say to one that breaks an oath?

**WARWICK**  
That he hath broke his faith with God and man,  
And from them both stands excommunicate.

**KING EDWARD**  
What office were it, to suggest a man  
To break a lawful and religious vow?

**WARWICK**  
An office for the devil, not for man.

**KING EDWARD**  
That devil's office must thou do for me,  
Or break thy oath, or cancel all the bonds  
Of love and duty twixt thyself and me;  
And therefore, Warwick, if thou art thyself,  
The Lord and master of thy word and oath,  
Go to thy daughter; and in my behalf  
Command her, woo her, win her any ways,  
To be my mistress and my secret love.  
I will not stand to hear thee make reply:  
Thy oath break hers, or let thy sovereign die.

*Exit.*

**WARWICK**  
O doting King! O detestable office!  
Well may I tempt myself to wrong myself,  
When he hath sworn me by the name of God  
To break a vow made by the name of God.  
What, if I swear by this right hand of mine  
To cut this right hand off? The better way  
Were to profane the Idol than confound it:  
But neither will I do; I'll keep mine oath,  
And to my daughter make a recantation  
Of all the virtue I have preacht to her:  
I'll say, she must forget her husband Salisbury,  
If she remember to embrace the King;  
I'll say, an oath may easily be broken,  
But not so easily pardoned, being broken;  
I'll say, it is true charity to love,  
But not true love to be so charitable;  
I'll say, his greatness may bear out the shame,  
But not his kingdom can buy out the sin;  
I'll say, it is my duty to persuade,  
But not her honesty to give consent.

*Enter Countess.*

See where she comes; was never father had  
Against his child an embassage so bad?

**COUNTESS**  
My Lord and father, I have sought for you:  
My mother and the Peers importune you  
To keep in presence of his majesty,  
And do your best to make his highness merry.

**WARWICK**  
*[Aside.]*  
How shall I enter in this graceless arrant?  
I must not call her child, for where's the father  
That will in such a suit seduce his child?  
Then, "wife of Salisbury"; shall I so begin?  
No, he's my friend, and where is found the friend  
That will do friendship such indammagement?

*[To the Countess.]*  
Neither my daughter nor my dear friend's wife,  
I am not Warwick, as thou thinkst I am,  
But an attorney from the court of hell,  
That thus have housed my spirit in his form,  
To do a message to thee from the King.  
The mighty King of England dotes on thee:  
He that hath power to take away thy life,  
Hath power to take thy honor; then consent  
To pawn thine honor rather than thy life:  
Honor is often lost and got again,  
But life, once gone, hath no recovery.  
The Sun, that withers hay, doth nourish grass;  
The King, that would disdain thee, will advance thee.  
The Poets write that great Achilles' spear  
Could heal the wound it made: the moral is,  
What mighty men misdo, they can amend.  
The lion doth become his bloody jaws,  
And grace his forragement by being mild,  
When vassel fear lies trembling at his feet.  
The King will in his glory hide thy shame;  
And those that gaze on him to find out thee,  
Will lose their eyesight, looking in the sun.  
What can one drop of poison harm the sea,  
Whose huge vastures can digest the ill  
And make it loose his operation?  
The King's great name will temper thy misdeeds,  
And give the bitter potion of reproach,  
A sugared, sweet and most delicious taste.  
Besides, it is no harm to do the thing  
Which without shame could not be left undone.  
Thus have I in his majesty's behalf  
Appareled sin in virtuous sentences,  
And dwell upon thy answer in his suit.

**COUNTESS**  
Unnatural besiege! Woe me unhappy,  
To have escaped the danger of my foes,  
And to be ten times worse injured by friends!  
Hath he no means to stain my honest blood,  
But to corrupt the author of my blood  
To be his scandalous and vile solicitor?  
No marvel though the branches be then infected,  
When poison hath encompassed the root:  
No marvel though the leprous infant die,  
When the stern dame invenometh the Dug.  
Why then, give sin a passport to offend,  
And youth the dangerous reign of liberty:  
Blot out the strict forbidding of the law,  
And cancel every cannon that prescribes  
A shame for shame or penance for offense.  
No, let me die, if his too boistrous will  
Will have it so, before I will consent  
To be an actor in his graceless lust.

**WARWICK**  
Why, now thou speakst as I would have thee speak:  
And mark how I unsay my words again.  
An honorable grave is more esteemed  
Than the polluted closet of a King:  
The greater man, the greater is the thing,  
Be it good or bad, that he shall undertake:  
An unreputed mote, flying in the sun,  
Presents a greater substance than it is:  
The freshest summer's day doth soonest taint  
The loathed carrion that it seems to kiss:  
Deep are the blows made with a mighty axe:  
That sin doth ten times aggravate itself,  
That is committed in a holy place:  
An evil deed, done by authority,  
Is sin and subornation: deck an ape  
In tissue, and the beauty of the robe  
Adds but the greater scorn unto the beast.  
A spatious field of reasons could I urge  
Between his glory, daughter, and thy shame:  
That poison shews worst in a golden cup;  
Dark night seems darker by the lightning flash;  
Lilies that fester smell far worse than weeds;  
And every glory that inclines to sin,  
The shame is treble by the opposite.  
So leave I with my blessing in thy bosom,  
Which then convert to a most heavy curse,  
When thou convertest from honor's golden name  
To the black faction of bed blotting shame.

**COUNTESS**  
I'll follow thee; and when my mind turns so,  
My body sink my soul in endless woe!

*Exeunt.*

### SCENE II. Roxborough. Another part of the castle.

*Enter at one door Derby from France, At another door Audley
with a Drum.*

**DERBY**  
Thrice noble Audley, well encount'red here!  
How is it with our sovereign and his peers?

**AUDLEY**  
'Tis full a fortnight, since I saw his highness  
What time he sent me forth to muster men;  
Which I accordingly have done, and bring them hither  
In fair array before his majesty.  
What news, my Lord of Derby, from the Emperor?

**DERBY**  
As good as we desire: the Emperor  
Hath yielded to his highness friendly aid,  
And makes our King lieutenant general  
In all his lands and large dominions;  
Then via! For the spatious bounds of France!

**AUDLEY**  
What, doth his highness leap to hear these news?

**DERBY**  
I have not yet found time to open them;  
The King is in his closet, malcontent;  
For what, I know not, but he gave in charge,  
Till after dinner none should interrupt him:  
The Countess Salisbury and her father Warwick,  
Artois and all look underneath the brows.

**AUDLEY**  
Undoubtedly, then, something is amiss.

*Trumpet within.*

**DERBY**  
The trumpets sound, the King is now abroad.

*Enter the King.*

**AUDLEY**  
Here comes his highness.

**DERBY**  
Befall my sovereign all my sovereign's wish!

**KING EDWARD**  
Ah, that thou wert a witch to make it so!

**DERBY**  
The Emperor greeteth you. ...  
*[Presenting Letters.]*

**KING EDWARD**  
*[Aside.]*  
... Would it were the Countess!

**DERBY**  
And hath accorded to your highness suite.

**KING EDWARD**  
*[Aside.]*  
Thou liest, she hath not; but I would she had.

**AUDLEY**  
All love and duty to my Lord the King!

**KING EDWARD**  
*[Aside.]*  
Well, all but one is none.—What news with you?

**AUDLEY**  
I have, my liege, levied those horse and foot  
According to your charge, and brought them hither.

**KING EDWARD**  
Then let those foot trudge hence upon those horse  
According to our discharge, and be gone.—  
Derby, I'll look upon the Countess' mind anon.

**DERBY**  
The Countess' mind, my liege?

**KING EDWARD**  
I mean the Emperour—leave me alone.  

**AUDLEY**  
What is his mind? ...

**DERBY**  
... Let's leave him to his humor.

*Exeunt.*

**KING EDWARD**  
Thus from the heart's aboundance speaks the tongue;  
Countess for Emperor: and, indeed, why not?  
She is as imperator over me, and I to her  
Am as a kneeling vassal, that observes  
The pleasure or displeasure of her eye.

*Enter Lodowick.*

What says the more than Cleopatra's match  
To Caesar now? ...

**LODOWICK**  
... That yet, my liege, ere night  
She will resolve your majesty.

*Drum within.*

**KING EDWARD**  
What drum is this that thunders forth this march,  
To start the tender Cupid in my bosom?  
Poor sheepskin, how it brawls with him that beateth it!  
Go, break the thundring parchment bottom out,  
And I will teach it to conduct sweet lines  
Unto the bosom of a heavenly nymph;  
For I will use it as my writing paper,  
And so reduce him from a scolding drum  
To be the herald and dear counsel bearer  
Betwixt a goddess and a mighty King.  
Go, bid the drummer learn to touch the Lute,  
Or hang him in the braces of his drum,  
For now we think it an uncivil thing,  
To trouble heaven with such harsh resounds:  
Away!

*Exit Lodowick.*

The quarrel that I have requires no arms  
But these of mine: and these shall meet my foe  
In a deep march of penetrable groans;  
My eyes shall be my arrows, and my sighs  
Shall serve me as the vantage of the wind,  
To whirl away my sweetest artillery.  
Ah, but, alas, she wins the sun of me,  
For that is she herself, and thence it comes  
That poets term the wanton warrior blind;  
But love hath eyes as judgement to his steps,  
Till too much loved glory dazzles them.—

*Enter Lodowick.*

How now?

**LODOWICK**  
My liege, the drum that stroke the lusty march,  
Stands with Prince Edward, your thrice valiant son.

*Enter Prince Edward.*

**KING EDWARD**  
I see the boy; oh, how his mother's face,  
Modeled in his, corrects my strayed desire,  
And rates my heart, and chides my thievish eye,  
Who, being rich enough in seeing her,  
Yet seeks elsewhere: and basest theft is that  
Which cannot cloak itself on poverty.—  
Now, boy, what news?

**PRINCE EDWARD**  
I have assembled, my dear Lord and father,  
The choicest buds of all our English blood  
For our affairs in France; and here we come  
To take direction from your majesty.

**KING EDWARD**  
*[Aside]*  
Still do I see in him delineate  
His mother's visage; those his eyes are hers,  
Who, looking wistely on me, make me blush:  
For faults against themselves give evidence;  
Lust is fire, and men like lanterns show  
Light lust within themselves, even through themselves.  
Away, loose silks of wavering vanity!  
Shall the large limit of fair Britain be  
By me be overthrown, and shall I not  
Master this little mansion of myself?  
Give me an armor of eternal steel!  
I go to conquer kings; and shall I not then  
Subdue myself? And be my enemy's friend?  
It must not be.—Come, boy, forward, advance!  
Let's with our colors sweet the air of France.

*Enter Lodowick.*

**LODOWICK**  
My liege, the Countess with a smiling cheer  
Desires access unto your Majesty.

**KING EDWARD**  
Why, there it goes! That very smile of hers  
Hath ransomed captive France, and set the King,  
The Dauphin, and the peers at liberty.—  
Go, leave me, Ned, and revel with thy friends.

*Exit Prince Edward.*

Thy mother is but black, and thou, like her,  
Do'st put it in my mind how foul she is—  
Go, fetch the Countess hither in thy hand,  
And let her chase away these winter clouds,  
For she gives beauty both to heaven and earth.

*Exit Lodowick.*

The sin is more to hack and hew poor men,  
Than to embrace in an unlawful bed  
The register of all rarities  
Since leatheren Adam till this youngest hour.

*Enter Countess escorted by Lodowick.*

Go, Lodowick, put thy hand into my purse,  
Play, spend, give, riot, waste, do what thou wilt,  
So thou wilt hence awhile and leave me here.

*Exit Lodowick.*

Now, my soul's playfellow, art thou come  
To speak the more than heavenly word of "yea"  
To my objection in thy beauteous love?

**COUNTESS**  
My father on his blessing hath commanded—

**KING EDWARD**  
That thou shalt yield to me?

**COUNTESS**  
Aye, dear my liege, your due.

**KING EDWARD**  
And that, my dearest love, can be no less  
Than right for right and tender love for love.

**COUNTESS**  
Then wrong for wrong and endless hate for hate—  
But — sith I see your majesty so bent,  
That my unwillingness, my husband's love,  
Your high estate, nor no respect respected  
Can be my help, but that your mightiness  
Will overbear and awe these dear regards—  
I bind my discontent to my content,  
And what I would not I'll compel I will,  
Provided that yourself remove those lets  
That stand between your highness' love and mine.

**KING EDWARD**  
Name them, fair Countess, and, by heaven, I will.

**COUNTESS**  
It is their lives that stand between our love,  
That I would have choked up, my sovereign.

**KING EDWARD**  
Whose lives, my Lady? ...

**COUNTESS**  
... My thrice loving liege,  
Your Queen and Salisbury, my wedded husband,  
Who living have that title in our love,  
That we cannot bestow but by their death.

**KING EDWARD**  
Thy opposition is beyond our Law.

**COUNTESS**  
So is your desire: if the law  
Can hinder you to execute the one,  
Let it forbid you to attempt the other.  
I cannot think you love me as you say,  
Unless you do make good what you have sworn.

**KING EDWARD**  
No more; thy husband and the Queen shall die.  
Fairer thou art by far than Hero was,  
Beardless Leander not so strong as I:  
He swom an easy current for his love,  
But I will through a Hellespont of blood,  
To arrive at Sestos where my Hero lies.

**COUNTESS**  
Nay, you'll do more; you'll make the river to  
With their heart bloods that keep our love asunder,  
Of which my husband and your wife are twain.

**KING EDWARD**  
Thy beauty makes them guilty of their death  
And gives in evidence that they shall die;  
Upon which verdict I, their Judge, condemn them.

**COUNTESS**  
*[Aside.]*  
O perjured beauty, more corrupted judge!  
When to the great star-chamber o'er our heads  
The universal sessions calls to count  
This packing evil, we both shall tremble for it.

**KING EDWARD**  
What says my fair love? Is she resolute?

**COUNTESS**  
Resolute to be dissolute; and, therefore, this:  
Keep but thy word, great King, and I am thine.  
Stand where thou dost, I'll part a little from thee,  
And see how I will yield me to thy hands.

*[Turning suddenly upon him, and showing two daggers.]*  
Here by my side doth hang my wedding knives:  
Take thou the one, and with it kill thy Queen,  
And learn by me to find her where she lies;  
And with this other I'll dispatch my love,  
Which now lies fast asleep within my heart:  
When they are gone, then I'll consent to love.  
Stir not, lascivious King, to hinder me;  
My resolution is more nimbler far,  
Than thy prevention can be in my rescue,  
And if thou stir, I strike; therefore, stand still,  
And hear the choice that I will put thee to:  
Either swear to leave thy most unholy suit  
And never hence forth to solicit me;  
Or else, by heaven, this sharp-pointed knife  
Shall stain thy earth with that which thou would stain,  
My poor chaste blood. Swear, Edward, swear,  
Or I will strike and die before thee here.

**KING EDWARD**  
Even by that power I swear, that gives me now  
The power to be ashamed of myself,  
I never mean to part my lips again  
In any words that tends to such a suit.  
Arise, true English Lady, whom our isle  
May better boast of than ever Roman might  
Of her, whose ransacked treasury hath taskt  
The vain endeavor of so many pens:  
Arise, and be my fault thy honor's fame,  
Which after ages shall enrich thee with.  
I am awakened from this idle dream.—  
Warwick, my son, Derby, Artois, and Audley!  
Brave warriors all, where are you all this while?

*Enter all.*

Warwick, I make thee Warden of the North:—  
Thou, Prince of Wales, and Audley, straight to sea;  
Scour to Newhaven; some there stay for me:  
Myself, Artois, and Derby will through Flanders,  
To greet our friends there and to crave their aide.  
This night will scarce suffice a faithful lover;  
For, ere the sun shall gild the eastern sky,  
We'll wake him with our martial harmony.

*Exeunt.*

# ACT III  

### SCENE I. Flanders. The French camp.

*Enter King John of France, his two sons, Charles of 
Normandy, and Philip, and the Duke of Lorraine.*

**KING JOHN**  
Here, till our navy of a thousand sail  
Have made a breakfast to our foe by sea,  
Let us encamp, to wait their happy speed.—  
Lorraine, what readiness is Edward in?  
How hast thou heard that he provided is  
Of martial furniture for this exploit?

**LORRAINE**  
To lay aside unnecessary soothing,  
And not to spend the time in circumstance,  
'Tis bruited for a certainty, my Lord,  
That he's exceeding strongly fortified;  
His subjects flock as willingly to war,  
As if unto a triumph they were led.

**CHARLES**  
England was wont to harbor malcontents,  
Blood thirsty and seditious Catelynes,  
Spend thrifts, and such as gape for nothing else  
But changing and alteration of the state;  
And is it possible  
That they are now so loyal in themselves?

**LORRAINE**  
All but the Scot, who solemnly protests,  
As heretofore I have informed his grace,  
Never to sheath his sword or take a truce.

**KING JOHN**  
Ah, that's the anchorage of some better hope!  
But, on the other side, to think what friends  
King Edward hath retained in Netherland,  
Among those ever-bibbing Epicures,  
Those frothy Dutch men, puff'd with double beer,  
That drink and swill in every place they come,  
Doth not a little aggravate mine ire;  
Besides, we hear, the Emperor conjoins,  
And stalls him in his own authority;  
But, all the mightier that their number is,  
The greater glory reaps the victory.  
Some friends have we beside domestic power;  
The stern Polonian, and the warlike Dane,  
The King of Boheme and of Sicily,  
Are all become confederates with us,  
And, as I think, are marching hither apace.

*Drum within.*

But soft, I hear the music of their drums,  
By which I guess that their approach is near.

*Enter the King of Bohemia, with Danes, and a Polish 
Captain, with other soldiers, another way.*

**KING OF BOHEMIA**  
King John of France, as league and neighborhood  
Requires, when friends are any way distrest,  
I come to aide thee with my country's force.

**POL CAPTAIN**  
And from great Moscow, fearful to the Turk,  
And lofty Poland, nurse of hardy men,  
I bring these servitors to fight for thee,  
Who willingly will venture in thy cause.

**KING JOHN**  
Welcome, Bohemian King, and welcome all:  
This your great kindness I will not forget.  
Besides your plentiful rewards in crowns,  
That from our treasury ye shall receive,  
There comes a hare brained nation, decked in pride,  
The spoil of whom will be a treble gain.  
And now my hope is full, my joy complete:  
At sea, we are as puissant as the force  
Of Agamemnon in the haven of Troy;  
By land, with Zerxes we compare of strength,  
Whose soldiers drank up rivers in their thirst;  
Then Bayard-like, blind, overweaning Ned,  
To reach at our imperial diadem  
Is either to be swallowed of the waves,  
Or hacked a pieces when thou comest ashore.

*Enter French Mariner.*

**FRENCH MARINER**  
Near to the coast I have descried, my Lord,  
As I was buy in my watchful charge,  
The proud armado of King Edward's ships:  
Which, at the first, far off when I did ken,  
Seemed as it were a grove of withered pines;  
But, drawing near, their glorious bright aspect,  
Their streaming ensigns, wrought of colored silk,  
Like to a meadow full of sundry flowers,  
Adorns the naked bosom of the earth:  
Majestical the order of their course,  
Figuring the horned circle of the moon:  
And on the top gallant of the admiral  
And likewise all the handmaids of his train  
The arms of England and of France unite  
Are quartered equally by heralds' art:  
Thus, tightly carried with a merry gale,  
They plough the ocean hitherward amain.

**KING JOHN**  
Dare he already crop the Fleur de Luce?  
I hope, the honey being gathered thence,  
He, with the spider, afterward approached,  
Shall suck forth deadly venom from the leaves.—  
But where's our navy? How are they prepared  
To wing themselves against this flight of ravens?

**FRENCH MARINER**  
They, having knowledge, brought them by the scouts,  
Did break from Anchor straight, and, puffed with rage,  
No otherwise then were their sails with wind,  
Made forth, as when the empty eagle flies,  
To satisfy his hungry griping maw.

**KING JOHN**  
There's for thy news. Return unto thy bark;  
And if thou scape the bloody stroke of war  
And do survive the conflict, come again,  
And let us hear the manner of the fight.

*Exit French Mariner.*

Mean space, my lords, 'tis best we be dispersed  
To several places, least they chance to land:  
First you, my Lord, with your Bohemian troops,  
Shall pitch your battailes on the lower hand;  
My eldest son, the Duke of Normandy,  
Together with the aide of Muscovites,  
Shall climb the higher ground another way;  
Here in the middle cost, betwixt you both,  
Philip, my youngest boy, and I will lodge.  
So, lords, be gone, and look unto your charge:  
You stand for France, an empire fair and large.

*Exeunt.*

Now tell me, Philip, what is thy concept,  
Touching the challenge that the English make?

**PHILIP**  
I say, my Lord, claim Edward what he can,  
And bring he ne'er so plain a pedigree,  
'Tis you are in the possession of the crown,  
And that's the surest point of all the law:  
But, were it not, yet ere he should prevail,  
I'll make a conduit of my dearest blood,  
Or chase those straggling upstarts home again.

**KING JOHN**  
Well said, young Philip! Call for bread and wine,  
That we may cheer our stomachs with repast,  
To look our foes more sternly in the face.

*A table and provisions brought in. The battle hard a far
off.*

Now is begun the heavy day at sea:  
Fight, Frenchmen, fight! Be like the field of bears,  
When they defend their younglings in the caves!  
Stir, angry nemesis, the happy helm,  
That, with the sulphur battles of your rage,  
The English fleet may be dispersed and sunk.

*Shot.*

**PHILIP**  
O Father, how this echoing cannon shot,  
Like sweet harmony, digests my eats!

**KING JOHN**  
Now, boy, thou hearest what thundering terror 'tis  
To buckle for a kingdom's sovereignty:  
The earth, with giddy trembling when it shakes,  
Or when the exhalations of the air  
Breaks in extremity of lightning flash,  
Affrights not more than kings, when they dispose  
To shew the rancor of their high swollen hearts.

*Retreat.*

Retreat is sounded; one side hath the worse;  
O, if it be the French, sweet fortune, turn;  
And, in thy turning, change the forward winds,  
That, with advantage of a favoring sky,  
Our men may vanquish, and the other fly!

*Enter French Mariner.*

My heart misgives:—say, mirror of pale death,  
To whom belongs the honor of this day?  
Relate, I pray thee, if thy breath will serve,  
The sad discourse of this discomfiture.

**FRENCH MARINER**  
I will, my Lord.  
My gracious sovereign, France hath ta'en the foil,  
And boasting Edward triumphs with success.  
These iron-hearted navies,  
When last I was reporter to your grace,  
Both full of angry spleen, of hope, and fear,  
Hasting to meet each other in the face,  
At last conjoined; and by their admiral  
Our admiral encountered many shot:  
By this, the other, that beheld these twain  
Give earnest penny of a further wrack,  
Like fiery dragons took their haughty flight;  
And, likewise meeting, from their smoky wombs  
Sent many grim ambassadors of death.  
Then 'gan the day to turn to gloomy night,  
And darkness did as well enclose the quick  
As those that were but newly reft of life.  
No leisure served for friends to bid farewell;  
And, if it had, the hideous noise was such,  
As each to other seemed deaf and dumb.  
Purple the sea, whose channel filled as fast  
With streaming gore, that from the maimed fell,  
As did her gushing moisture break into  
The crannied cleftures of the through shot planks.  
Here flew a head, dissever'd from the trunk,  
There mangled arms and legs were tossed aloft,  
As when a whirl wind takes the summer dust  
And scatters it in middle of the air.  
Then might ye see the reeling vessels split,  
And tottering sink into the ruthless flood,  
Until their lofty tops were seen no more.  
All shifts were tried, both for defense and hurt:  
And now the effect of valor and of force,  
Of resolution and of cowardice,  
We lively pictures; how the one for fame,  
The other by compulsion laid about;  
Much did the Nonpareille, that brave ship;  
So did the Black Snake of Bullen, then which  
A bonnier vessel never yet spread sail.  
But all in vain; both sun, the wind and tide,  
Revolted all unto our foe men's side,  
That we perforce were fain to give them way,  
And they are landed.—Thus my tale is done:  
We have untimely lost, and they have won.

**KING JOHN**  
Then rests there nothing, but with present speed  
To join our several forces all in one,  
And bid them battle, ere they range too far.  
Come, gentle Philip, let us hence depart;  
This soldier's words have pierced thy father's heart.

*Exeunt.*

### SCENE II. Picardy. The fields near Cressy.

*Enter three Frenchmen; a Frenchwoman and two little 
children meet them, and other Citizens.*

**THIRD FRENCH**  
Well met, my masters: how now? What's the news?  
And wherefore are ye laden thus with stuff?  
What, is it quarter-day that you remove,  
And carry bag and baggage too?

**FIRST FRENCH**  
Quarter-day? Aye, and quartering day, I fear:  
Have ye not heard the news that flies abroad?

**THIRD FRENCH**  
What news?

**SECOND FRENCH**  
How the French navy is destroy'd at sea,  
And that the English army is arrived.

**THIRD FRENCH**  
What then?

**FIRST FRENCH**  
What then, quoth you? Why, ist not time to fly,  
When envy and destruction is so nigh?

**THIRD FRENCH**  
Content thee, man: they are far enough from hence,  
And will be met, I warrant ye, to their cost,  
Before they break so far into the realm.

**FIRST FRENCH**  
Aye, so the grasshopper doth spend the time  
In mirthful jollity, till winter come;  
And then too late he would redeem his time,  
When frozen cold hath nipped his careless head.  
He, that no sooner will provide a cloak,  
Then when he sees it doth begin to reign,  
May, peradventure, for his negligence,  
Be throughly washed, when he suspects it not.  
We that have charge and such a train as this,  
Must look in time to look for them and us,  
Least, when we would, we cannot be relieved.

**THIRD FRENCH**  
Belike, you then despair of all success,  
And think your country will be subjugate.

**SECOND FRENCH**  
We cannot tell; 'tis good to fear the worst.

**THIRD FRENCH**  
Yet rather fight, then, like unnatural sons,  
Forsake your loving parents in distress.

**FIRST FRENCH**  
Tush, they that have already taken arms  
Are many fearful millions in respect  
Of that small handful of our enemies;  
But 'tis a rightful quarrel must prevail;  
Edward is son unto our late King's sister,  
When John Valois is three degrees removed.

**FRENCHWOMAN**  
Besides, there goes a prophecy abroad,  
Published by one that was a friar once,  
Whose oracles have many times proved true;  
And now he says, the time will shortly come,  
When as a lion, roused in the west,  
Shall carry hence the fluerdeluce of France:  
These, I can tell ye, and such like surmises  
Strike many French men cold unto the heart.

*Enter a Fourth Frenchman.*

**FOURTH FRENCH**  
Fly, country men and citizens of France!  
Sweet flowering peace, the root of happy life,  
Is quite abandoned and expulst the land;  
Instead of whom ransacked constraining war  
Sits like to ravens upon your houses' tops;  
Slaughter and mischief walk within your streets,  
And, unrestrained, make havoc as they pass;  
The form whereof even now myself beheld  
Upon this fair mountain whence I came.  
For so far of as I directed mine eyes,  
I might perceive five cities all on fire,  
Corn fields and vineyards, burning like an oven;  
And, as the reaking vapor in the wind  
Turned but aside, I like wise might discern  
The poor inhabitants, escaped the flame,  
Fall numberless upon the soldiers' pikes.  
Three ways these dreadful ministers of wrath  
Do tread the measures of their tragic march:  
Upon the right hand comes the conquering King,  
Upon the left his hot unbridled son,  
And in the midst our nation's glittering host,  
All which, though distant yet, conspire in one,  
To leave a desolation where they come.  
Fly therefore, citizens, if you be wise,  
Seek out some habitation further off:  
Here if you stay, your wives will be abused,  
Your treasure shared before your weeping eyes;  
Shelter you yourselves, for now the storm doth rise.  
Away, away; me thinks I hear their drums:—  
Ah, wretched France, I greatly fear thy fall;  
Thy glory shaketh like a tottering wall.

*Exeunt.*

### SCENE III. Picardy. The fields near Cressy.

*Enter King Edward, and the Earl of Derby, with Soldiers, 
and Gobin de Grey.*

**KING EDWARD**  
Where's the Frenchman by whose cunning guide  
We found the shallow of this river Somme,  
And had directions how to pass the sea?

**GOBIN**  
Here, my good Lord.

**KING EDWARD**  
How art thou called? Tell me thy name.

**GOBIN**  
Gobin de Grey, if please your excellence.

**KING EDWARD**  
Then, Gobin, for the service thou hast done,  
We here enlarge and give thee liberty;  
And, for recompense beside this good,  
Thou shalt receive five hundred marks in gold.—  
I know not how, we should have met our son,  
Whom now in heart I wish I might behold.

*Enter Artois.*

**ARTOIS**  
Good news, my Lord; the Prince is hard at hand,  
And with him comes Lord Audley and the rest,  
Whom since our landing we could never meet.

*Drums sound. Enter Prince Edward, Lord Audley, and Soldiers.*

**KING EDWARD**  
Welcome, fair Prince! How hast thou sped, my son,  
Since thy arrival on the coast of France?

**PRINCE EDWARD**  
Successfully, I thank the gracious heavens:  
Some of their strongest cities we have won,  
As Harfleur, Lo, Crotay, and Carentigne,  
And others wasted, leaving at our heels  
A wide apparent field and beaten path  
For solitariness to progress in:  
Yet those that would submit we kindly pardoned,  
But who in scorn refused our proffered peace,  
Endured the penalty of sharp revenge.

**KING EDWARD**  
Ah, France, why should'st thou be thus obstinate  
Against the kind embracement of thy friends?  
How gently had we thought to touch thy breast  
And set our foot upon thy tender mould,  
But that, in froward and disdainful pride,  
Thou, like a skittish and untamed colt,  
Do'st start aside and strike us with thy heels!  
But tell me, Ned, in all thy warlike course,  
Hast thou not seen the usurping King of France?

**PRINCE EDWARD**  
Yes, my good Lord, and not two hours ago,  
With full a hundred thousand fighting men—  
Upon the one side of the river's bank  
And on the other both, his multitudes.  
I feared he would have cropped our smaller power:  
But happily, perceiving your approach,  
He hath with drawn himself to Cressy plains;  
Where, as it seemeth by his good array,  
He means to bid us battle presently.

**KING EDWARD**  
He shall be welcome; that's the thing we crave.

*Drums. Enter King John, the Dukes of Normandy and Lorraine,
King of Bohemia, young Prince Philip, and Soldiers.*

**KING JOHN**  
Edward, know that John, the true King of France,  
Musing thou shouldst encroach upon his land,  
And in thy tyrannous proceeding slay  
His faithful subjects and subvert his towns,  
Spits in thy face; and in this manner following  
Upbraids thee with thine arrogant intrusion:  
First, I condemn thee for a fugitive,  
A thievish pirate, and a needy mate,  
One that hath either no abiding place,  
Or else, inhabiting some barren soil,  
Where neither herb or fruitful grain is had,  
Doest altogether live by pilfering:  
Next, insomuch thou hast infringed thy faith,  
Broke liege and solemn covenant made with me,  
I hold thee for a false pernicious wretch:  
And, last of all, although I scorn to cope  
With one so much inferior to myself,  
Yet, in respect thy thirst is all for gold,  
Thy labour rather to be feared than loved,  
To satisfy thy lust in either part,  
Here am I come, and with me have I brought  
Exceeding store of treasure, pearl, and coin.  
Leave, therefore, now to persecute the weak,  
And armed entering conflict with the armed,  
Let it be seen, 'mong'st other petty thefts,  
How thou canst win this pillage manfully.

**KING EDWARD**  
If gall or wormwood have a pleasant taste,  
Then is thy salutation honey sweet;  
But as the one hath no such property,  
So is the other most satirical.  
Yet wot how I regard thy worthless taunts:  
If thou have uttered them to foil my fame  
Or dim the reputation of my birth,  
Know that thy wolvish barking cannot hurt;  
If slyly to insinuate with the world,  
And with a strumpet's artificial line  
To paint thy vicious and deformed cause,  
Be well assured, the counterfeit will fade,  
And in the end thy foul defects be seen;  
But if thou didst it to provoke me on,  
As who should say I were but timorous.  
Or, coldly negligent, did need a spur,  
Bethink thyself how slack I was at sea,  
How since my landing I have won no towns,  
Entered no further but upon the coast,  
And there have ever since securely slept.  
But if I have been otherwise employed,  
Imagine, Valois, whether I intend  
To skirmish, not for pillage, but for the crown  
Which thou dost wear; and that I vow to have,  
Or one of us shall fall into his grave.

**PRINCE EDWARD**  
Look not for cross invectives at our hands,  
Or railing execrations of despite:  
Let creeping serpents, hid in hollow banks,  
Sting with their tongues; we have remorseless swords,  
And they shall plead for us and our affairs.  
Yet thus much, briefly, by my father's leave:  
As all the immodest poison of thy throat  
Is scandalous and most notorious lies,  
And our pretended quarrel is truly just,  
So end the battle when we meet today:  
May either of us prosper and prevail,  
Or, luckless, curst, receive eternal shame!

**KING EDWARD**  
That needs no further question; and I know,  
His conscience witnesseth, it is my right.—  
Therefore, Valois, say, wilt thou yet resign,  
Before the sickles thrust into the corn,  
Or that inkindled fury turn to flame?

**KING JOHN**  
Edward, I know what right thou hast in France;  
And ere I basely will resign my crown,  
This champion field shall be a pool of blood,  
And all our prospect as a slaughter house.

**PRINCE EDWARD**  
Aye, that approves thee, tyrant, what thou art:  
No father, King, or shepherd of thy realm,  
But one, that tears her entrails with thy hands,  
And, like a thirsty tiger, suckst her blood.

**AUDLEY**  
You peers of France, why do you follow him  
That is so prodigal to spend your lives?

**CHARLES**  
Whom should they follow, aged impotent,  
But he that is their true borne sovereign?

**KING EDWARD**  
Upbraidst thou him, because within his face  
Time hath ingraved deep characters of age?  
Know, these grave scholars of experience,  
Like stiff grown oaks, will stand immovable,  
When whirl wind quickly turns up younger trees.

**DERBY**  
Was ever any of thy father's house  
King but thyself, before this present time?  
Edward's great linage, by the mother's side,  
Five hundred years hath held the sceptre up:  
Judge then, conspirators, by this descent,  
Which is the true borne sovereign, this or that.

**PHILIP**  
Father, range your battles, prate no more;  
These English fain would spend the time in words,  
That, night approaching, they might escape unfought.

**KING JOHN**  
Lords and my loving subjects, now's the time,  
That your intended force must bide the touch.  
Therefore, my friends, consider this in brief:  
He that you fight for is your natural King;  
He against whom you fight, a foreigner:  
He that you fight for, rules in clemency,  
And reins you with a mild and gentle bit;  
He against whom you fight, if he prevail,  
Will straight inthrone himself in tyranny,  
Makes slaves of you, and with a heavy hand  
Curtail and curb your sweetest liberty.  
Then, to protect your country and your King,  
Let but the haughty courage of your hearts  
Answer the number of your able hands,  
And we shall quickly chase these fugitives.  
For what's this Edward but a belly god,  
A tender and lascivious wantoness,  
That thother day was almost dead for love?  
And what, I pray you, is his goodly guard?  
Such as, but scant them of their chines of beef  
And take away their downy featherbeds,  
And presently they are as resty stiff,  
As 'twere a many over ridden jades.  
Then, Frenchmen, scorn that such should be your lords,  
And rather bind ye them in captive bands.

**ALL FRENCHMEN**  
Vive le Roy! God save King John of France!

**KING JOHN**  
Now on this plain of Cressy spread yourselves,—  
And, Edward, when thou darest, begin the fight.

*Exeunt King John, Charles, Philip, Lorraine, Boheme, and 
forces.*

**KING EDWARD**  
We presently will meet thee, John of France:—  
And, English lords, let us resolve this day,  
Either to clear us of that scandalous crime,  
Or be intombed in our innocence.  
And, Ned, because this battle is the first  
That ever yet thou foughtest in pitched field,  
As ancient custom is of martialists,  
To dub thee with the tip of chivalry,  
In solemn manner we will give thee arms.  
Come, therefore, heralds, orderly bring forth  
A strong attirement for the Prince my son.

*Enter four Heralds, bringing in a coat-armor, a helmet, a
lance, and a shield.*

*The first Herald delivers the armor to King Edward, who 
puts it on his son.*

**KING EDWARD**  
Edward Plantagenet, in the name of God,  
As with this armor I impale thy breast,  
So be thy noble unrelenting heart  
Walled in with flint of matchless fortitude,  
That never base affections enter there:  
Fight and be valiant, conquer where thou comest!  
Now follow, lords, and do him honor to.

**DERBY**  
Edward Plantagenet, Prince of Wales,  
As I do set this helmet on thy head,  
Wherewith the chamber of thy brain is fenc'd,  
So may thy temples, with Bellona's hand,  
Be still adorned with laurel victory:  
Fight and be valiant, conquer where thou comest!

**AUDLEY**  
Edward Plantagenet, Prince of Wales,  
Receive this lance into thy manly hand;  
Use it in fashion of a brazen pen,  
To draw forth bloody stratagems in France,  
And print thy valiant deeds in honor's book:  
Fight and be valiant, vanquish where thou comest!

**ARTOIS**  
Edward Plantagenet, Prince of Wales,  
Hold, take this target, wear it on thy arm;  
And may the view thereof, like Perseus' shield,  
Astonish and transform thy gazing foes  
To senseless images of meager death:  
Fight and be valiant, conquer where thou comest!

**KING EDWARD**  
Now wants there nought but knighthood, which deferred  
We leave, till thou hast won it in the field.

**PRINCE EDWARD**  
My gracious father and ye forward peers,  
This honor you have done me, animates  
And cheers my green, yet scarce appearing strength  
With comfortable good presaging signs,  
No other wise than did old Jacob's words,  
When as he breathed his blessings on his sons.  
These hallowed gifts of yours when I profane,  
Or use them not to glory of my God,  
To patronage the fatherless and poor,  
Or for the benefit of England's peace,  
Be numb my joints, wax feeble both mine arms,  
Wither my heart, that, like a sapless tree,  
I may remain the map of infamy.

**KING EDWARD**  
Then thus our steeled battles shall be ranged:  
The leading of the vaward, Ned, is thine;  
To dignify whose lusty spirit the more,  
We temper it with Audley's gravity,  
That, courage and experience joined in one,  
Your manage may be second unto none:  
For the main battles, I will guide myself;  
And, Derby, in the rearward march behind,  
That orderly disposed and set in ray,  
Let us to horse; and God grant us the day!

*Exeunt.*

# INTERMISSION    


### SCENE IV. Picardy. The fields near Cressy.

*Alarum.*

*Enter a many Frenchmen flying. After them Prince Edward,
running.*

*Enter King John and Duke of Lorraine.*

**KING JOHN**  
Oh, Lorraine, say, what mean our men to fly?  
Our number is far greater than our foes.

**LORRAINE**  
The garrison of Genoaes, my Lord,  
That came from Paris weary with their march,  
Grudging to be so suddenly employ'd,  
No sooner in the forefront took their place,  
But, straight retiring, so dismayed the rest,  
As likewise they betook themselves to flight,  
In which, for haste to make a safe escape,  
More in the clustering throng are pressed to death,  
Than by the enemy, a thousand fold.

**KING JOHN**  
O hapless fortune! Let us yet assay,  
If we can counsel some of them to stay.

*Exeunt.*

### SCENE V. The Same.

*Enter King Edward and Audley.*

**KING EDWARD**  
Lord Audley, whiles our son is in the chase,  
With draw our powers unto this little hill,  
And here a season let us breath ourselves.

**AUDLEY**  
I will, my Lord.

*Exit. Sound Retreat.*

**KING EDWARD**  
Just dooming heaven, whose secret providence  
To our gross judgement is inscrutable,  
How are we bound to praise thy wondrous works,  
That hast this day given way unto the right,  
And made the wicked stumble at themselves!

*Enter Artois.*

**ARTOIS**  
Rescue, King Edward! Rescue for thy son!

**KING EDWARD**  
Rescue, Artois? What, is he prisoner,  
Or by violence fell beside his horse?

**ARTOIS**  
Neither, my Lord: but narrowly beset  
With turning Frenchmen, whom he did pursue,  
As 'tis impossible that he should 'scape,  
Except your highness presently descend.

**KING EDWARD**  
Tut, let him fight; we gave him arms today,  
And he is laboring for a knighthood, man.

*Enter Derby.*

**DERBY**  
The Prince, my Lord, the Prince! Oh, succor him!  
He's close incompast with a world of odds!

**KING EDWARD**  
Then will he win a world of honor too,  
If he by valor can redeem him thence;  
If not, what remedy? We have more sons  
Than one, to comfort our declining age.

*Enter Audley.*


**AUDLEY**  
Renowned Edward, give me leave, I pray,  
To lead my soldiers where I may relieve  
Your Grace's son, in danger to be slain.  
The snares of French, like emmets on a bank,  
Muster about him; whil'st he, lion-like,  
Intangled in the net of their assaults,  
Franticly wrends, and bites the woven toil;  
But all in vain, he cannot free himself.

**KING EDWARD**  
Audley, content; I will not have a man,  
On pain of death, sent forth to succor him:  
This is the day, ordained by destiny,  
To season his courage with those grievous thoughts,  
That, if he breaketh out, Nestor's years on earth  
Will make him savor still of this exploit.

**DERBY**  
Ah, but he shall not live to see those days.

**KING EDWARD**  
Why, then his epitaph is lasting praise.

**AUDLEY**  
Yet, good my Lord, 'tis too much willfulness,  
To let his blood be spilt, that may be saved.

**KING EDWARD**  
Exclaim no more; for none of you can tell  
Whether a borrowed aid will serve, or no;  
Perhaps he is already slain or ta'en.  
And dare a falcon when she's in her flight,  
And ever after she'll be haggard like:  
Let Edward be delivered by our hands,  
And still, in danger, he'll expect the like;  
But if himself himself redeem from thence,  
He will have vanquished cheerful death and fear,  
And ever after dread their force no more  
Than if they were but babes or captive slaves.

**AUDLEY**  
O cruel Father! Farewell, Edward, then!

**DERBY**  
Farewell, sweet Prince, the hope of chivalry!

**ARTOIS**  
O, would my life might ransom him from death!

*Retreat sounded.*

**KING EDWARD**  
But soft, me thinks I hear  
The dismal charge of trumpets' loud retreat.  
All are not slain, I hope, that went with him;  
Some will return with tidings, good or bad.

*Enter Prince Edward in triumph, bearing in his hands his
chivered lance, and the King of Bohemia, borne before,
wrapped in the colors. They run and embrace him.*

**AUDLEY**  
O joyful sight! Victorious Edward lives!

**DERBY**  
Welcome, brave Prince!

**KING EDWARD**  
Welcome, Plantagenet!

**PRINCE EDWARD**  
*[Kneels and kisses his father's hand.]*  
First having done my duty as beseemed,  
Lords, I regreet you all with hearty thanks.  
And now, behold, after my winter's toil,  
My painful voyage on the boisterous sea  
Of wars devouring gulfs and steely rocks,  
I bring my fraught unto the wished port,  
My summer's hope, my travels' sweet reward:  
And here, with humble duty, I present  
This sacrifice, this first fruit of my sword,  
Cropped and cut down even at the gate of death,  
The King of Boheme, father, whom I slew;  
Whose thousands had entrenched me round about,  
And lay as thick upon my battered crest,  
As on an anvil, with their ponderous glaves:  
Yet marble courage still did underprop  
And when my weary arms, with often blows,  
Like the continual laboring wood-man's Axe  
That is enjoined to fell a load of oaks,  
Began to faulter, straight I would record  
My gifts you gave me, and my zealous vow,  
And then new courage made me fresh again,  
That, in despite, I carved my passage forth,  
And put the multitude to speedy flight.  
Lo, thus hath Edward's hand filled your request,  
And done, I hope, the duty of a knight.

**KING EDWARD**  
Aye, well thou hast deserved a knighthood, Ned!  
And, therefore, with thy sword, yet reeking warm

*His sword borne by a soldier.*

With blood of those that fought to be thy bane.  
Arise, Prince Edward, trusty knight at arms:  
This day thou hast confounded me with joy,  
And proud thyself fit heir unto a King.

**PRINCE EDWARD**  
Here is a note, my gracious Lord, of those  
That in this conflict of our foes were slain:  
Eleven princes of esteem, four score barons,  
A hundred and twenty knights, and thirty thousand  
Common soldiers; and, of our men, a thousand.

**KING EDWARD**  
Our God be praised! Now, John of France, I hope,  
Thou knowest King Edward for no wantoness,  
No love sick cockney, nor his soldiers jades.  
But which way is the fearful King escaped?

**PRINCE EDWARD**  
Towards Poitiers, noble father, and his sons.

**KING EDWARD**  
Ned, thou and Audley shall pursue them still;  
Myself and Derby will to Calice straight,  
And there be begirt that haven town with siege.  
Now lies it on an upshot; therefore strike,  
And wistly follow, whiles the game's on foot.  
What picture's this? ...

**PRINCE EDWARD**  
... A pelican, my Lord,  
Wounding her bosom with her crooked beak,  
That so her nest of young ones may be fed  
With drops of blood that issue from her heart;  
The motto, Sic et vos: "And so should you".

*Exeunt.*

# ACT IV  

### SCENE I. Bretagne. The camp of the English.

*Enter Lord Mountford with a Coronet in his hand; with him
the Earl of Salisbury.*

**MOUNTFORD**  
My Lord of Salisbury, since by your aide  
Mine enemy Sir Charles of Blois is slain,  
And I again am quietly possessed  
In Britain's dukedom, know that I resolve,  
For this kind furtherance of your King and you,  
To swear allegiance to his majesty:  
In sign whereof receive this coronet,  
Bear it unto him, and, withal, mine oath,  
Never to be but Edward's faithful friend.

**SALISBURY**  
I take it, Mountford. Thus, I hope, ere long  
The whole dominions of the realm of France  
Will be surrendered to his conquering hand.

*Exit Mountford.*

Now, if I knew but safely how to pass,  
I would at Calais gladly meet his Grace,  
Whether I am by letters certified  
That he intends to have his host removed.  
It shall be so, this policy will serve:—  
Ho, who's within? Bring Villiers to me.

*Enter Villiers.*

Villiers, thou knowest, thou art my prisoner,  
And that I might for ransom, if I would,  
Require of thee a hundred thousand francs,  
Or else retain and keep thee captive still:  
But so it is, that for a smaller charge  
Thou mayst be quit, and if thou wilt thyself.  
And this it is: procure me but a passport  
Of Charles, the Duke of Normandy, that I  
Without restraint may have recourse to Calais  
Through all the Countries where he hath to do;  
Which thou mayst easily obtain, I think,  
By reason I have often heard thee say,  
He and thou were students once together:  
And then thou shalt be set at liberty.  
How sayest thou? Wilt thou undertake to do it?

**VILLIERS**  
I will, my Lord; but I must speak with him.

**SALISBURY**  
Why, so thou shalt; take horse, and post from hence:  
Only before thou goest, swear by thy faith,  
That, if thou canst not compass my desire,  
Thou wilt return my prisoner back again;  
And that shall be sufficient warrant for me.

**VILLIERS**  
To that condition I agree, my Lord,  
And will unfainedly perform the same.

*Exit.*

**SALISBURY**  
Farewell, Villiers.—  
Thus once I mean to try a Frenchman's faith.

*Exit.*

### SCENE II. Picardy. The English Camp before Calais.

*Enter King Edward and Derby, with Soldiers.*

**KING EDWARD**  
Since they refuse our proffered league, my Lord,  
And will not ope their gates, and let us in,  
We will entrench ourselves on every side,  
That neither victuals nor supply of men  
May come to succor this accursed town:  
Famine shall combat where our swords are stopped.

*Enter six poor Frenchmen, including a Poor Inhabitant of
Calais.*

**DERBY**  
The promised aid, that made them stand aloof,  
Is now retired and gone another way:  
It will repent them of their stubborn will.  
But what are these poor ragged slaves, my Lord?

**KING EDWARD**  
Ask what they are; it seems, they come from Calais.

**DERBY**  
You wretched patterns of despair and woe,  
What are you, living men or gliding ghosts,  
Crept from your graves to walk upon the earth?

**FIRST POOR FRENCHMAN**  
No ghosts, my Lord, but men that breath a life  
Far worse than is the quiet sleep of death:  
We are distressed poor inhabitants,  
That long have been diseased, sick, and lame;  
And now, because we are not fit to serve,  
The captain of the town hath thrust us forth,  
That so expense of victuals may be saved.

**KING EDWARD**  
A charitable deed, no doubt, and worthy praise!  
But how do you imagine then to speed?  
We are your enemies; in such a case  
We can no less but put ye to the sword,  
Since, when we proffered truce, it was refused.

**SECOND POOR FRENCHMAN**  
And if your grace no otherwise vouchsafe,  
As welcome death is unto us as life.

**KING EDWARD**  
Poor silly men, much wronged and more distressed!  
Go, Derby, go, and see they be relieved;  
Command that victuals be appointed them,  
And give to every one five crowns a piece.

*Exeunt Derby and Frenchmen.*

The lion scorns to touch the yielding prey,  
And Edward's sword must flesh itself in such  
As willful stubbornness hath made perverse.

*Enter Lord Percy.*

Lord Percy! Welcome: what's the news in England?

**PERCY**  
The Queen, my Lord, comes here to your Grace,  
And from her highness and the Lord viceregent  
I bring this happy tidings of success:  
David of Scotland, lately up in arms,  
Thinking, belike, he soonest should prevail,  
Your highness being absent from the realm,  
Is, by the fruitful service of your peers  
And painful travel of the Queen herself,  
That, big with child, was every day in arms,  
Vanquished, subdued, and taken prisoner.

**KING EDWARD**  
Thanks, Percy, for thy news, with all my heart!  
What was he took him prisoner in the field?

**PERCY**  
An esquire, my Lord; John Copland is his name:  
Who since, intreated by her Majesty,  
Denies to make surrender of his prize  
To any but unto your grace alone;  
Whereat the Queen is grievously displeas'd.

**KING EDWARD**  
Well, then we'll have a Pursiuvant despatched,  
To summon Copland hither out of hand,  
And with him he shall bring his prisoner King.

**PERCY**  
The Queen's, my Lord, herself by this at sea,  
And purposeth, as soon as wind will serve,  
To land at Calais, and to visit you.

**KING EDWARD**  
She shall be welcome; and, to wait her coming,  
I'll pitch my tent near to the sandy shore.

*Enter First French Captain.*

**FIRST FRENCH CAPTAIN**  
The Burgesses of Calais, mighty King,  
Have by a counsel willingly decreed  
To yield the town and castle to your hands,  
Upon condition it will please your grace  
To grant them benefit of life and goods.

**KING EDWARD**  
They will so! Then, belike, they may command,  
Dispose, elect, and govern as they list.  
No, sirrah, tell them, since they did refuse  
Our princely clemency at first proclaimed,  
They shall not have it now, although they would;  
I will accept of nought but fire and sword,  
Except, within these two days, six of them,  
That are the wealthiest merchants in the town,  
Come naked, all but for their linen shirts,  
With each a halter hanged about his neck,  
And prostrate yield themselves, upon their knees,  
To be afflicted, hanged, or what I please;  
And so you may inform their masterships.

*Exeunt Edward and Percy.*

**FIRST FRENCH CAPTAIN**  
Why, this it is to trust a broken staff:  
Had we not been persuaded, John our King  
Would with his army have relieved the town,  
We had not stood upon defiance so:  
But now 'tis past that no man can recall,  
And better some do go to wrack them all.

*Exit.*

### SCENE III. Poitou. Fields near Poitiers. The French camp; tent of the Duke of Normandy.

*Enter Charles of Normandy and Villiers.*

**CHARLES**  
I wonder, Villiers, thou shouldest importune me  
For one that is our deadly enemy.

**VILLIERS**  
Not for his sake, my gracious Lord, so much  
Am I become an earnest advocate,  
As that thereby my ransom will be quit.

**CHARLES**  
Thy ransom, man? Why needest thou talk of that?  
Art thou not free? And are not all occasions,  
That happen for advantage of our foes,  
To be accepted of, and stood upon?

**VILLIERS**  
No, good my Lord, except the same be just;  
For profit must with honor be comixt,  
Or else our actions are but scandalous.  
But, letting pass their intricate objections,  
Wilt please your highness to subscribe, or no?

**CHARLES**  
Villiers, I will not, nor I cannot do it;  
Salisbury shall not have his will so much,  
To claim a passport how it pleaseth himself.

**VILLIERS**  
Why, then I know the extremity, my Lord;  
I must return to prison whence I came.

**CHARLES**  
Return? I hope thou wilt not;  
What bird that hath escaped the fowler's gin,  
Will not beware how she's ensnared again?  
Or, what is he, so senseless and secure,  
That, having hardly past a dangerous gul,  
Will put himself in peril there again?

**VILLIERS**  
Ah, but it is mine oath, my gracious Lord,  
Which I in conscience may not violate,  
Or else a kingdom should not draw me hence.

**CHARLES**  
Thine oath? Why, tat doth bind thee to abide:  
Hast thou not sworn obedience to thy Prince?

**VILLIERS**  
In all things that uprightly he commands:  
But either to persuade or threaten me,  
Not to perform the covenant of my word,  
Is lawless, and I need not to obey.

**CHARLES**  
Why, is it lawful for a man to kill,  
And not, to break a promise with his foe?

**VILLIERS**  
To kill, my Lord, when war is once proclaimed,  
So that our quarrel be for wrongs received,  
No doubt, is lawfully permitted us;  
But in an oath we must be well advised,  
How we do swear, and, when we once have sworn,  
Not to infringe it, though we die therefore:  
Therefore, my Lord, as willing I return,  
As if I were to fly to paradise.

**CHARLES**  
Stay, my Villiers; thine honorable man  
Deserves to be eternally admired.  
Thy suit shall be no longer thus deferred:  
Give me the paper, I'll subscribe to it;  
And, wheretofore I loved thee as Villiers,  
Hereafter, I'll embrace thee as myself.  
Stay, and be still in favor with thy Lord.

**VILLIERS**  
I humbly thank you grace; I must dispatch,  
And send this passport first unto the Earl,  
And then I will attend your highness pleasure.

**CHARLES**  
Do so, Villiers — and Charles, when he hath need,  
Be such his soldiers, howsoever he speed!

*Exit Villiers.*

*Enter King John.*

**KING JOHN**  
Come, Charles, and arm thee; Edward is entrapped,  
The Prince of Wales is fallen into our hands,  
And we have compassed him; he cannot escape.

**CHARLES**  
But will your highness fight today?

**KING JOHN**  
What else, my son? He's scarce eight thousand strong,  
And we are threescore thousand at the least.

**CHARLES**  
I have a prophecy, my gracious Lord,  
Wherein is written what success is like  
To happen us in this outrageous war;  
It was delivered me at Cresses field  
By one that is an aged Hermit there.

*[Reads.]*  
When feathered fowl shall make thine army tremble,   
And flint stones rise and break the battle ray,   
Then think on him that doth not now dissemble;   
For that shall be the hapless dreadful day:   
Yet, in the end, thy foot thou shalt advance   
As far in England as thy foe in France.

**KING JOHN**  
By this it seems we shall be fortunate:  
For as it is impossible that stones  
Should ever rise and break the battle ray,  
Or airy foul make men in arms to quake,  
So is it like, we shall not be subdued:  
Or say this might be true, yet in the end,  
Since he doth promise we shall drive him hence  
And forage their country as they have done ours,  
By this revenge that loss will seem the less.  
But all are frivolous fancies, toys, and dreams:  
Once we are sure we have ensnared the son,  
Catch we the father after how we can.

*Exeunt.*

### SCENE IV. The same. The English camp.

*Enter Prince Edward, Audley, and others.*

**PRINCE EDWARD**  
Audley, the arms of death embrace us round,  
And comfort have we none, save that to die  
We pay sower earnest for a sweeter life.  
At Cressey field out Clouds of Warlike smoke  
Choked up those French mouths and dissevered them;  
But now their multitudes of millions hide,  
Masking as twere, the beauteous burning sun,  
Leaving no hope to us, but sullen dark  
And eyeless terror of all ending night.

**AUDLEY**  
This sudden, mighty, and expedient head  
That they have made, fair Prince, is wonderful.  
Before us in the valley lies the King,  
Vantaged with all that heaven and earth can yield;  
His party stronger battled than our whole:  
His son, the braving Duke of Normandy,  
Hath trimmed the mountain on our right hand up  
In shining plate, that now the aspiring hill  
Shews like a silver quarry or an orb,  
Aloft the which the banners, bannarets,  
And new replenished pendants cuff the air  
And beat the winds, that for their gaudiness  
Struggles to kiss them: on our left hand lies  
Philip, the younger issue of the King,  
Coating the other hill in such array,  
That all his guilded upright pikes do seem  
Straight trees of gold, the pendants leaves;  
And their device of antique heraldry,  
Quartered in colors, seeming sundry fruits,  
Makes it the orchard of the Hesperides:  
Behind us too the hill doth bear his height,  
For like a half-moon, opening but one way,  
It rounds us in; there at our backs are lodged  
The fatal crossbows, and the battle there  
Is governed by the rough Chatillion.  
Then thus it stands: the valley for our flight  
The King binds in; the hills on either hand  
Are proudly royalized by his sons;  
And on the Hill behind stands certain death  
In pay and service with Chatillion.

**PRINCE EDWARD**  
Death's name is much more mighty than his deeds;  
Thy parcelling this power hath made it more.  
As many sands as these my hands can hold,  
Are but my handful of so many sands;  
Then, all the world, and call it but a power,  
Easily ta'en up, and quickly thrown away:  
But if I stand to count them sand by sand,  
The number would confound my memory,  
And make a thousand millions of a task,  
Which briefly is no more, indeed, than one.  
These quarters, squadrons, and these regiments,  
Before, behind us, and on either hand,  
Are but a power. When we name a man,  
His hand, his foot, his head hath several strengths;  
And being all but one self instant strength,  
Why, all this many, Audley, is but one,  
And we can call it all but one man's strength.  
He that hath far to go, tells it by miles;  
If he should tell the steps, it kills his heart:  
The drops are infinite, that make a flood,  
And yet, thou knowest, we call it but a Rain.  
There is but one France, one King of France,  
That France hath no more kings; and that same King  
Hath but the puissant legion of one King,  
And we have one: then apprehend no odds,  
For one to one is fair equality.

*Enter First French Herald from King John.*

**PRINCE EDWARD**  
What tidings, messenger? Be plain and brief.

**FIRST FRENCH HERALD**  
The King of France, my sovereign Lord and master,  
Greets by me his foe, the Prince of Wales:  
If thou call forth a hundred men of name,  
Of lords, knights, squires, and English gentlemen,  
And with thyself and those kneel at his feet,  
He straight will fold his bloody colors up,  
And ransom shall redeem lives forfeited;  
If not, this day shall drink more English blood,  
Than ere was buried in our British earth.  
What is the answer to his proffered mercy?

**PRINCE EDWARD**  
This heaven, that covers France, contains the mercy  
That draws from me submissive orisons;  
That such base breath should vanish from my lips,  
To urge the plea of mercy to a man,  
The Lord forbid! Return, and tell the King,  
My tongue is made of steel, and it shall beg  
My mercy on his coward burgonet;  
Tell him, my colors are as red as his,  
My men as bold, our English arms as strong:  
Return him my defiance in his face.

**FIRST FRENCH HERALD**  
I go.

*Exit.*

*Enter a Second French Herald.*

**PRINCE EDWARD**  
What news with thee?

**SECOND FRENCH HERALD**  
The Duke of Normandy, my Lord and master,  
Pitying thy youth is so ingirt with peril,  
By me hath sent a nimble-jointed jennet,  
As swift as ever yet thou didst bestride,  
And therewithall he counsels thee to fly;  
Else death himself hath sworn that thou shalt die.

**PRINCE EDWARD**  
Back with the beast unto the beast that sent him!  
Tell him I cannot sit a coward's horse;  
Bid him today bestride the jade himself,  
For I will stain my horse quite o'er with blood,  
And double gild my spurs, but I will catch him;  
So tell the cap'ring boy, and get thee gone.

*Exit French Herald.*

*Enter a Third French Herald.*

**THIRD FRENCH HERALD**  
Edward of Wales, Philip, the second son  
To the most mighty christian King of France,  
Seeing thy body's living date expired,  
All full of charity and christian love,  
Commends this book, full fraught with prayers,  
To thy fair hand and for thy hour of life  
Intreats thee that thou meditate therein,  
And arm thy soul for her long journey towards—  
Thus have I done his bidding, and return.

**PRINCE EDWARD**  
Herald of Philip, greet thy Lord from me:  
All good that he can send, I can receive;  
But thinkst thou not, the unadvised boy  
Hath wronged himself in thus far tendering me?  
Happily he cannot pray without the book—  
I think him no divine extemporall—,  
Then render back this common place of prayer,  
To do himself good in adversity;  
Beside he knows not my sins' quality,  
And therefore knows no prayers for my avail;  
Ere night his prayer may be to pray to God,  
To put it in my heart to hear his prayer.  
So tell the courtly wanton, and be gone.

**THIRD FRENCH HERALD**  
I go.

*Exit.*

**PRINCE EDWARD**  
How confident their strength and number makes them!—  
Now, Audley, sound those silver wings of thine,  
And let those milk white messengers of time  
Shew thy times learning in this dangerous time.  
Thyself art bruis'd and bit with many broils,  
And stratagems forepast with iron pens  
Are texted in thine honorable face;  
Thou art a married man in this distress,  
But danger woos me as a blushing maid:  
Teach me an answer to this perilous time.

**AUDLEY**  
To die is all as common as to live:  
The one ince-wise, the other holds in chase;  
For, from the instant we begin to live,  
We do pursue and hunt the time to die:  
First bud we, then we blow, and after seed,  
Then, presently, we fall; and, as a shade  
Follows the body, so we follow death.  
If, then, we hunt for death, why do we fear it?  
If we fear it, why do we follow it?  
If we do fear, how can we shun it?  
If we do fear, with fear we do but aide  
The thing we fear to seize on us the sooner:  
If we fear not, then no resolved proffer  
Can overthrow the limit of our fate;  
For, whether ripe or rotten, drop we shall,  
As we do draw the lottery of our doom.

**PRINCE EDWARD**  
Ah, good old man, a thousand thousand armors  
These words of thine have buckled on my back:  
Ah, what an idiot hast thou made of life,  
To seek the thing it fears! And how disgraced  
The imperial victory of murdering death,  
Since all the lives his conquering arrows strike  
Seek him, and he not them, to shame his glory!  
I will not give a penny for a life,  
Nor half a halfpenny to shun grim death,  
Since for to live is but to seek to die,  
And dying but beginning of new life.  
Let come the hour when he that rules it will!  
To live or die I hold indifferent.

*Exeunt.*

### SCENE V. The same. The French camp.

*Enter King John and Charles.*

**KING JOHN**  
A sudden darkness hath defaced the sky,  
The winds are crept into their caves for fear,  
The leaves move not, the world is hushed and still,  
The birds cease singing, and the wandering brooks  
Murmur no wonted greeting to their shores;  
Silence attends some wonder and expecteth  
That heaven should pronounce some prophecy:  
Where, or from whom, proceeds this silence, Charles?

**CHARLES**  
Our men, with open mouths and staring eyes,  
Look on each other, as they did attend  
Each other's words, and yet no creature speaks;  
A tongue-tied fear hath made a midnight hour,  
And speeches sleep through all the waking regions.

**KING JOHN**  
But now the pompous sun, in all his pride,  
Looked through his golden coach upon the world,  
And, on a sudden, hath he hid himself,  
That now the under earth is as a grave,  
Dark, deadly, silent, and uncomfortable.

*A clamor of ravens.*

Hark, what a deadly outcry do I hear?

**CHARLES**  
Here comes my brother Philip. ...

**KING JOHN**  
... All dismayed:

*Enter Philip.*

What fearful words are those thy looks presage?

**PHILIP**  
A flight, a flight!

**KING JOHN**  
Coward, what flight? Thou liest, there needs no flight.

**PHILIP**  
A flight.

**KING JOHN**  
Awake thy craven powers, and tell on  
The substance of that very fear indeed,  
Which is so ghastly printed in thy face:  
What is the matter? ...

**PHILIP**  
... A flight of ugly ravens  
Do croak and hover o'er our soldiers' heads,  
And keep in triangles and cornered squares,  
Right as our forces are embattled;  
With their approach there came this sudden fog,  
Which now hath hid the airy floor of heaven  
And made at noon a night unnatural  
Upon the quaking and dismayed world:  
In brief, our soldiers have let fall their arms,  
And stand like metamorphosed images,  
Bloodless and pale, one gazing on another.

**KING JOHN**  
Aye, now I call to mind the prophecy,  
But I must give no entrance to a fear.—  
Return, and hearten up these yielding souls:  
Tell them, the ravens, seeing them in arms,  
So many fair against a famished few,  
Come but to dine upon their handy work  
And prey upon the carrion that they kill:  
For when we see a horse laid down to die,  
Although he be not dead, the ravenous birds  
Sit watching the departure of his life;  
Even so these ravens for the carcasses  
Of those poor English, that are marked to die,  
Hover about, and, if they cry to us,  
'Tis but for meat that we must kill for them.  
Away, and comfort up my soldiers,  
And sound the trumpets, and at once dispatch  
This little business of a silly fraud.

*Exit Philip.*

*Another noise. Salisbury brought in by the Second French 
Captain.*

**SECOND FRENCH CAPTAIN**  
Behold, my liege, this knight and forty mo',  
Of whom the better part are slain and fled,  
With all endeavor sought to break our ranks,  
And make their way to the encompassed Prince:  
Dispose of him as please your majesty.

**KING JOHN**  
Go, and the next bough, soldier, that thou seest,  
Disgrace it with his body presently;  
For I do hold a tree in France too good  
To be the gallows of an English thief.

**SALISBURY**  
My Lord of Normandy, I have your pass  
And warrant for my safety through this land.

**CHARLES**  
Villiers procured it for thee, did he not?

**SALISBURY**  
He did.

**CHARLES**  
And it is current; thou shalt freely pass.

**KING JOHN**  
Aye, freely to the gallows to be hanged,  
Without denial or impediment.  
Away with him!

**CHARLES**  
I hope your highness will not so disgrace me,  
And dash the virtue of my seal at arms:  
He hath my never broken name to show,  
Charactered with this princely hand of mine:  
And rather let me leave to be a Prince  
Than break the stable verdict of a Prince:  
I do beseech you, let him pass in quiet.

**KING JOHN**  
Thou and thy word lie both in my command:  
What canst thou promise that I cannot break?  
Which of these twain is greater infamy,  
To disobey thy father or thyself?  
Thy word, nor no mans, may exceed his power;  
Nor that same man doth never break his word,  
That keeps it to the utmost of his power.  
The breach of faith dwells in the soul's consent:  
Which if thyself without consent do break,  
Thou art not charged with the breach of faith.  
Go, hang him: for thy license lies in me,  
And my constraint stands the excuse for thee.

**CHARLES**  
What, am I not a soldier in my word?  
Then, arms, adieu, and let them fight that list!  
Shall I not give my girdle from my waste,  
But with a guardian I shall be controlled,  
To say I may not give my things away?  
Upon my soul, had Edward, Prince of Wales,  
Engaged his word, writ down his noble hand  
For all your knights to pass his father's land,  
The royal King, to grace his warlike son,  
Would not alone safe conduct give to them,  
But with all bounty feasted them and theirs.

**KING JOHN**  
Dwell'st thou on precedents? Then be it so!  
Say, Englishman, of what degree thou art.

**SALISBURY**  
An Earl in England, though a prisoner here,  
And those that know me, call me Salisbury.

**KING JOHN**  
Then, Salisbury, say whether thou art bound.

**SALISBURY**  
To Calais, where my liege, King Edward, is.

**KING JOHN**  
To Calais, Salisbury? Then, to Calais pack,  
And bid the King prepare a noble grave,  
To put his princely son, black Edward, in.  
And as thou travel'st westward from this place,  
Some two leagues hence there is a lofty hill,  
Whose top seems topless, for the embracing sky  
Doth hide his high head in her azure bosom;  
Upon whose tall top when thy foot attains,  
Look back upon the humble vale beneath—  
Humble of late, but now made proud with arms—  
And thence behold the wretched Prince of Wales,  
Hooped with a bond of iron round about.  
After which sight, to Calais spur amain,  
And say, the Prince was smothered and not slain:  
And tell the King this is not all his ill;  
For I will greet him, ere he thinks I will.  
Away, be gone; the smoke but of our shot  
Will choke our foes, though bullets hit them not.

*Exit.*

### SCENE IV. The same. A part of the field of battle.

*Alarum. Enter Prince Edward and Artois.*

**ARTOIS**  
How fares your grace? Are you not shot, my Lord?

**PRINCE EDWARD**  
No, dear Artois; but choked with dust and smoke,  
And stepped aside for breath and fresher air.

**ARTOIS**  
Breath, then, and to it again: the amazed French  
Are quite distract with gazing on the crows;  
And, were our quivers full of shafts again,  
Your grace should see a glorious day of this:—  
O, for more arrows, Lord; that's our want.

**PRINCE EDWARD**  
Courage, Artois! A fig for feather'd shafts,  
When feather'd fowls do bandy on our side.  
What need we fight, and sweat, and keep a coil,  
When railing crows outscold our adversaries?  
Up, up, Artois! The ground itself is armed  
With fire containing flint; command our bows  
To hurl away their pretty colore'd yew,  
And to it with stones: away, Artois, away!  
My soul doth prophecy we win the day.

*Exeunt.*

### SCENE VII. The same. Another part of the field of battle.

*Alarum.* 

*Enter King John.*

**KING JOHN**  
Our multitudes are in themselves confounded,  
Dismayed, and distraught; swift starting fear  
Hath buzzed a cold dismay through all our army,  
And every petty disadvantage prompts  
The fear possessed abject soul to fly.  
Myself, whose spirit is steel to their dull lead,  
What with recalling of the prophecy,  
And that our native stones from English arms  
Rebel against us, find myself attainted  
With strong surprise of weak and yielding fear.

*Enter Charles.*

**CHARLES**  
Fly, father, fly! The French do kill the French,  
Some that would stand let drive at some that fly;  
Our drums strike nothing but discouragement,  
Our trumpets sound dishonor and retire;  
The spirit of fear, that feareth nought but death,  
Cowardly works confusion on itself.

*Enter Philip.*

**PHILIP**  
Pluck out your eyes, and see not this day's shame!  
An arm hath beat an army; one poor David  
Hath with a stone foiled twenty stout Goliaths;  
Some twenty naked starvelings with small flints,  
Hath driven back a puissant host of men,  
Arrayed and fenced in all accomplements.

**KING JOHN**  
Mortdieu, they quait at us, and kill us up;  
No less than forty thousand wicked elders  
Have forty lean slaves this day stoned to death.

**CHARLES**  
O, that I were some other countryman!  
This day hath set derision on the French,  
And all the world will blurt and scorn at us.

**KING JOHN**  
What, is there no hope left?

**PHILIP**  
No hope, but death, to bury up our shame.

**KING JOHN**  
Make up once more with me; the twentieth part  
Of those that live, are men inow to quail  
The feeble handful on the adverse part.

**CHARLES**  
Then charge again: if heaven be not opposed,  
We cannot lose the day. ...

**KING JOHN**  
... On, away!

*Exeunt.*

### SCENE VIII. The same. Another part of the field of battle.

*Enter Audley, wounded, and rescued by two English
Esquires.*

**FIRST ESQUIRE**  
How fares my Lord? ...

**AUDLEY**  
... Even as a man may do,  
That dines at such a bloody feast as this.

**SECOND ESQUIRE**  
I hope, my Lord, that is no mortal scar.

**AUDLEY**  
No matter, if it be; the count is cast,  
And, in the worst, ends but a mortal man.  
Good friends, convey me to the princely Edward,  
That in the crimson bravery of my blood  
I may become him with saluting him.  
I'll smile, and tell him, that this open scar  
Doth end the harvest of his Audley's war.

*Exeunt.*

### SCENE IX. The same. The English camp.

*Enter Prince Edward, King John, Charles, and all, with
ensigns spread.*

**PRINCE EDWARD**  
Now, John in France, and lately John of France,  
Thy bloody ensigns are my captive colors;  
And you, high vaunting Charles of Normandy,  
That once today sent me a horse to fly,  
Are now the subjects of my clemency.  
Fie, lords! Is it not a shame that English boys,  
Whose early days are yet not worth a beard,  
Should in the bosom of your kingdom thus,  
One against twenty, beat you up together?

**KING JOHN**  
Thy fortune, not thy force, hath conquered us.

**PRINCE EDWARD**  
An argument that heaven aides the right.

*Enter Artois with Philip.*

See, see! Artois doth bring with him along  
The late good counsel giver to my soul.  
Welcome, Artois; and welcome, Philip, too:  
Who now of you or I have need to pray?  
Now is the proverb verified in you:  
"Too bright a morning breeds a low'ring day."

*Sound Trumpets. Enter Audley.*

But say, what grim discouragement comes here!  
Alas, what thousand armed men of France  
Have writ that note of death in Audley's face?  
Speak, thou that wooest death with thy careless smile,  
And lookst so merrily upon thy grave,  
As if thou were enamored on thine end:  
What hungry sword hath so bereaved thy face,  
And lopped a true friend from my loving soul?

**AUDLEY**  
O Prince, thy sweet bemoaning speech to me  
Is as a mournful knell to one dead-sick.

**PRINCE EDWARD**  
Dear Audley, if my tongue ring out thy end,  
My arms shall be thy grave: what may I do  
To win thy life, or to revenge thy death?  
If thou wilt drink the blood of captive kings,  
Or that it were restorative, command  
A health of kings' blood, and I'll drink to thee;  
If honor may dispense for thee with death,  
The never dying honor of this day  
Share wholly, Audley, to thyself, and live.

**AUDLEY**  
Victorious Prince — that thou art so, behold  
A Caesar's fame in King's captivity—  
If I could hold him death but at a bay,  
Till I did see my liege thy royal father,  
My soul should yield this castle of my flesh,  
This mangled tribute, with all willingness,  
To darkness, consummation, dust, and worms.

**PRINCE EDWARD**  
Cheerily, bold man, thy soul is all too proud  
To yield her city for one little breach;  
Should be divorced from her earthly spouse  
By the soft temper of a Frenchman's sword?  
Lo, to repair thy life, I give to thee  
Three thousand marks a year in English land.

**AUDLEY**  
I take thy gift, to pay the debts I owe:  
These two poor esquires redeemed me from the French  
With lusty and dear hazard of their lives:  
What thou hast given me, I give to them;  
And, as thou lovest me, Prince, lay thy consent  
To this bequeath in my last testament.

**PRINCE EDWARD**  
Renowned Audley, live, and have from me  
This gift twice doubled to these esquires and thee:  
But live or die, what thou hast given away  
To these and theirs shall lasting freedom stay.  
Come, gentlemen, I will see my friend bestowed  
With in an easy litter; then we'll march  
Proudly toward Calais, with triumphant pace,  
Unto my royal father, and there bring  
The tribute of my wars, fair France his King.

*Exit.*

# ACT V  

### SCENE I. Picardy. The English camp before Calais.

*Enter King Edward, Queen Philippa, Derby, soldiers.*

**KING EDWARD**  
No more, Queen Philip, pacify yourself;  
Copland, except he can excuse his fault,  
Shall find displeasure written in our looks.  
And now unto this proud resisting town!  
Soldiers, assault: I will no longer stay,  
To be deluded by their false delays;  
Put all to sword, and make the spoil your own.

*Enter six Citizens of Calais in their shirts, barefoot, 
with halters about their necks.*

**ALL CITIZENS of CALAIS**  
Mercy, King Edward, mercy, gracious Lord!

**KING EDWARD**  
Contemptuous villains, call ye now for truce?  
Mine ears are stopped against your bootless cries:—  
Sound, drums alarum; draw threatening swords!

**FIRST CITIZEN of CALAIS**  
Ah, noble Prince, take pity on this town,  
And hear us, mighty King:  
We claim the promise that your highness made;  
The two days' respite is not yet expired,  
And we are come with willingness to bear  
What torturing death or punishment you please,  
So that the trembling multitude be saved.

**KING EDWARD**  
My promise? Well, I do confess as much:  
But I do require the chiefest citizens  
And men of most account that should submit;  
You, peradventure, are but servile grooms,  
Or some felonious robbers on the sea,  
Whom, apprehended, law would execute,  
Albeit severity lay dead in us:  
No, no, ye cannot overreach us thus.

**SECOND CITIZEN of CALAIS**  
The sun, dread Lord, that in the western fall  
Beholds us now low brought through misery,  
Did in the Orient purple of the morn  
Salute our coming forth, when we were known;  
Or may our portion be with damned fiends.

**KING EDWARD**  
If it be so, then let our covenant stand:  
We take possession of the town in peace,  
But, for yourselves, look you for no remorse;  
But, as imperial justice hath decreed,  
Your bodies shall be dragged about these walls,  
And after feel the stroke of quartering steel:  
This is your doom;—go, soldiers, see it done.

**QUEEN PHILIP**  
Ah, be more mild unto these yielding men!  
It is a glorious thing to stablish peace,  
And kings approach the nearest unto God  
By giving life and safety unto men:  
As thou intendest to be King of France,  
So let her people live to call thee King;  
For what the sword cuts down or fire hath spoiled,  
Is held in reputation none of ours.

**KING EDWARD**  
Although experience teach us this is true,  
That peaceful quietness brings most delight,  
When most of all abuses are controlled;  
Yet, insomuch it shall be known that we  
As well can master our affections  
As conquer other by the dint of sword,  
Philip, prevail; we yield to thy request:  
These men shall live to boast of clemency,  
And, tyranny, strike terror to thyself.

**SECOND CITIZEN of CALAIS**  
Long live your highness! Happy be your reign!

**KING EDWARD**  
Go, get you hence, return unto the town,  
And if this kindness hath deserved your love,  
Learn then to reverence Edward as your King.—

*Exeunt Citizens of Calais.*

Now, might we hear of our affairs abroad,  
We would, till gloomy winter were o'er spent,  
Dispose our men in garrison a while.  
But who comes here?

*Enter Copland and King David.*

**DERBY**  
Copland, my Lord, and David, King of Scots.

**KING EDWARD**  
Is this the proud presumptuous esquire of the north,  
That would not yield his prisoner to my Queen?

**COPLAND**  
I am, my liege, a northern esquire indeed,  
But neither proud nor insolent, I trust.

**KING EDWARD**  
What moved thee, then, to be so obstinate  
To contradict our royal Queen's desire?

**COPLAND**  
No wilful disobedience, mighty Lord,  
But my desert and public law at arms:  
I took the King myself in single fight,  
And, like a soldiers, would be loath to lose  
The least pre-eminence that I had won.  
And Copland straight upon your highness' charge  
Is come to France, and with a lowly mind  
Doth vale the bonnet of his victory:  
Receive, dread Lord, the custom of my fraught,  
The wealthy tribute of my laboring hands,  
Which should long since have been surrendered up,  
Had but your gracious self been there in place.

**QUEEN PHILIP**  
But, Copland, thou didst scorn the King's command,  
Neglecting our commission in his name.

**COPLAND**  
His name I reverence, but his person more;  
His name shall keep me in allegiance still,  
But to his person I will bend my knee.

**KING EDWARD**  
I pray thee, Philip, let displeasure pass;  
This man doth please me, and I like his words:  
For what is he that will attempt great deeds,  
And lose the glory that ensues the same?  
All rivers have recourse unto the sea,  
And Copland's faith relation to his King.  
Kneel, therefore, down: now rise, King Edward's knight;  
And, to maintain thy state, I freely give  
Five hundred marks a year to thee and thine.

*Enter Salisbury.*

Welcome, Lord Salisbury: what news from Britain?

**SALISBURY**  
This, mighty King: the country we have won,  
And John de Mountford, regent of that place,  
Presents your highness with this coronet,  
Protesting true allegiance to your Grace.

**KING EDWARD**  
We thank thee for thy service, valiant Earl;  
Challenge our favor, for we owe it thee.

**SALISBURY**  
But now, my Lord, as this is joyful news,  
So must my voice be tragical again,  
And I must sing of doleful accidents.

**KING EDWARD**  
What, have our men the overthrow at Poictiers?  
Or is our son beset with too much odds?

**SALISBURY**  
He was, my Lord: and as my worthless self  
With forty other serviceable knights,  
Under safe conduct of the Dauphin's seal,  
Did travail that way, finding him distressed,  
A troop of lances met us on the way,  
Surprised, and brought us prisoners to the King,  
Who, proud of this, and eager of revenge,  
Commanded straight to cut off all our heads:  
And surely we had died, but that the Duke,  
More full of honor than his angry sire,  
Procured our quick deliverance from thence;  
But, ere we went, "Salute your King," quoth he,  
"Bid him provide a funeral for his son:  
Today our sword shall cut his thread of life;  
And, sooner than he thinks, we'll be with him,  
To quittance those displeasures he hath done."  
This said, we past, not daring to reply;  
Our hearts were dead, our looks diffused and wan.  
Wandering, at last we climbed unto a hill,  
From whence, although our grief were much before,  
Yet now to see the occasion with our eyes  
Did thrice so much increase our heaviness:  
For there, my Lord, oh, there we did descry  
Down in a valley how both armies lay.  
The French had cast their trenches like a ring,  
And every barricado's open front  
Was thick embossed with brazen ordinance;  
Here stood a battaile of ten thousand horse,  
There twice as many pikes in quadrant wise,  
Here crossbows, and deadly wounding darts:  
And in the midst, like to a slender point  
Within the compass of the horizon,  
—As twere a rising bubble in the sea,  
A hazel wand amidst a wood of pines,  
Or as a bear fast chained unto a stake—,  
Stood famous Edward, still expecting when  
Those dogs of France would fasten on his flesh.  
Anon the death procuring knell begins:  
Off go the cannons, that with trembling noise  
Did shake the very mountain where they stood;  
Then sound the trumpets' clangor in the air,  
The battles join: and, when we could no more  
Discern the difference twixt the friend and foe,  
So intricate the dark confusion was,  
Away we turned our watery eyes with sighs,  
As black as powder fuming into smoke.  
And thus, I fear, unhappy have I told  
The most untimely tale of Edward's fall.

**QUEEN PHILIP**  
Ah me, is this my welcome into France?  
Is this the comfort that I looked to have,  
When I should meet with my beloved son?  
Sweet Ned, I would thy mother in the sea  
Had been prevented of this mortal grief!

**KING EDWARD**  
Content thee, Philip; 'tis not tears will serve  
To call him back, if he be taken hence:  
Comfort thyself, as I do, gentle Queen,  
With hope of sharp, unheard of, dire revenge.—  
He bids me to provide his funeral,  
And so I will; but all the peers in France  
Shall mourners be, and weep out bloody tears,  
Until their empty veins be dry and sere:  
The pillars of his hearse shall be his bones;  
The mould that covers him, their city ashes;  
His knell, the groaning cries of dying men;  
And, in the stead of tapers on his tomb,  
An hundred fifty towers shall burning blaze,  
While we bewail our valiant son's decease.

*After a flourish, sounded within, enter an English Herald.*

**ENGLISH HERALD**  
Rejoice, my Lord; ascend the imperial throne!  
The mighty and redoubted Prince of Wales,  
Great servitor to bloody Mars in arms,  
The Frenchman's terror, and his country's fame,  
Triumphant rideth like a Roman peer,  
And, lowly at his stirrup, comes afoot  
King John of France, together with his son,  
In captive bonds; whose diadem he brings  
To crown thee with, and to proclaim thee King.

**KING EDWARD**  
Away with mourning, Philip, wipe thine eyes;—  
Sound, trumpets, welcome in Plantagenet!

*Enter Prince Edward, King John, Philip, Audley, Artois.*

As things long lost, when they are found again,  
So doth my son rejoice his father's heart,  
For whom even now my soul was much perplexed.

**QUEEN PHILIP**  
Be this a token to express my joy,  
*[Kisses him.]*  

For inward passion will not let me speak.

**PRINCE EDWARD**  
My gracious father, here receive the gift.

*[Presenting him with King John's crown.]*  
This wreath of conquest and reward of war,  
Got with as mickle peril of our lives,  
As ere was thing of price before this day;  
Install your highness in your proper right:  
And, herewithall, I render to your hands  
These prisoners, chief occasion of our strife.

**KING EDWARD**  
So, John of France, I see you keep your word:  
You promised to be sooner with ourself  
Than we did think for, and 'tis so indeed:  
But, had you done at first as now you do,  
How many civil towns had stood untouched,  
That now are turned to ragged heaps of stones!  
How many people's lives might'st thou have saved,  
That are untimely sunk into their graves!

**KING JOHN**  
Edward, recount not things irrevocable;  
Tell me what ransom thou requirest to have.

**KING EDWARD**  
Thy ransom, John, hereafter shall be known:  
But first to England thou must cross the seas,  
To see what entertainment it affords;  
How ere it falls, it cannot be so bad,  
As ours hath been since we arrived in France.

**KING JOHN**  
Accursed man! Of this I was foretold,  
But did misconster what the prophet told.

**PRINCE EDWARD**  
Now, father, this petition Edward makes  
To thee, whose grace hath been his strongest shield,  
That, as thy pleasure chose me for the man  
To be the instrument to shew thy power,  
So thou wilt grant that many princes more,  
Bred and brought up within that little Isle,  
May still be famous for like victories!  
And, for my part, the bloody scars I bear,  
And weary nights that I have watched in field,  
The dangerous conflicts I have often had,  
The fearful menaces were proffered me,  
The heat and cold and what else might displease:  
I wish were now redoubled twenty fold,  
So that hereafter ages, when they read  
The painful traffic of my tender youth,  
Might thereby be inflamed with such resolve,  
As not the territories of France alone,  
But likewise Spain, Turkey, and what countries else  
That justly would provoke fair England's ire,  
Might, at their presence, tremble and retire.

**KING EDWARD**  
Here, English lords, we do proclaim a rest,  
An intercession of our painful arms:  
Sheath up your swords, refresh your weary limbs,  
Peruse your spoils; and, after we have breathed  
A day or two within this haven town,  
God willing, then for England we'll be shipped;  
Where, in a happy hour, I trust, we shall  
Arrive, three kings, two princes, and a queen.
